/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
  CODE_FOR_adddi3_compareV = 5,
  CODE_FOR_addsi3_compareV = 6,
  CODE_FOR_adddi3_compareC = 8,
  CODE_FOR_addsi3_compareC = 10,
  CODE_FOR_addsi3_compare0 = 11,
  CODE_FOR_cmpsi2_addneg = 14,
  CODE_FOR_subdi3_compare1 = 27,
  CODE_FOR_subsi3_compare1 = 28,
  CODE_FOR_subsi3_compare0 = 42,
  CODE_FOR_subsi3_compare = 43,
  CODE_FOR_mulhisi3 = 69,
  CODE_FOR_maddhisi4 = 73,
  CODE_FOR_maddhidi4 = 76,
  CODE_FOR_insv_zero = 90,
  CODE_FOR_insv_t2 = 91,
  CODE_FOR_andsi_notsi_si = 96,
  CODE_FOR_andsi_not_shiftsi_si = 97,
  CODE_FOR_andsi_not_shiftsi_si_scc_no_reuse = 98,
  CODE_FOR_andsi_not_shiftsi_si_scc = 99,
  CODE_FOR_unaligned_loadsi = 135,
  CODE_FOR_unaligned_loadhis = 136,
  CODE_FOR_unaligned_loadhiu = 137,
  CODE_FOR_unaligned_storesi = 138,
  CODE_FOR_unaligned_storehi = 139,
  CODE_FOR_extzv_t2 = 141,
  CODE_FOR_divsi3 = 142,
  CODE_FOR_udivsi3 = 143,
  CODE_FOR_negdi2_compare = 144,
  CODE_FOR_zero_extendqidi2 = 157,
  CODE_FOR_zero_extendhidi2 = 158,
  CODE_FOR_zero_extendsidi2 = 159,
  CODE_FOR_extendqidi2 = 160,
  CODE_FOR_extendhidi2 = 161,
  CODE_FOR_extendsidi2 = 162,
  CODE_FOR_pic_load_addr_unified = 180,
  CODE_FOR_pic_load_addr_32bit = 181,
  CODE_FOR_pic_load_addr_thumb1 = 182,
  CODE_FOR_pic_add_dot_plus_four = 183,
  CODE_FOR_pic_add_dot_plus_eight = 184,
  CODE_FOR_tls_load_dot_plus_eight = 185,
   CODE_FOR_pic_offset_arm = CODE_FOR_nothing,
  CODE_FOR_arm_cond_branch = 201,
  CODE_FOR_blockage = 227,
  CODE_FOR_probe_stack = 228,
  CODE_FOR_probe_stack_range = 229,
  CODE_FOR_arm_casesi_internal = 230,
  CODE_FOR_nop = 233,
  CODE_FOR_trap = 234,
  CODE_FOR_movcond_addsi = 266,
  CODE_FOR_movcond = 267,
  CODE_FOR_stack_tie = 301,
  CODE_FOR_align_4 = 307,
  CODE_FOR_align_8 = 308,
  CODE_FOR_consttable_end = 309,
  CODE_FOR_consttable_1 = 310,
  CODE_FOR_consttable_2 = 311,
  CODE_FOR_consttable_4 = 312,
  CODE_FOR_consttable_8 = 313,
  CODE_FOR_consttable_16 = 314,
  CODE_FOR_clzsi2 = 315,
  CODE_FOR_rbitsi2 = 316,
  CODE_FOR_ctzsi2 = 317,
  CODE_FOR_prefetch = 318,
  CODE_FOR_force_register_use = 319,
  CODE_FOR_arm_eh_return = 320,
  CODE_FOR_load_tp_hard = 321,
  CODE_FOR_load_tp_soft = 322,
  CODE_FOR_tlscall = 323,
  CODE_FOR_arm_rev16si2 = 328,
  CODE_FOR_arm_rev16si2_alt = 329,
  CODE_FOR_crc32b = 330,
  CODE_FOR_crc32h = 331,
  CODE_FOR_crc32w = 332,
  CODE_FOR_crc32cb = 333,
  CODE_FOR_crc32ch = 334,
  CODE_FOR_crc32cw = 335,
  CODE_FOR_cdp = 394,
  CODE_FOR_cdp2 = 395,
  CODE_FOR_mcr = 404,
  CODE_FOR_mcr2 = 405,
  CODE_FOR_mrc = 406,
  CODE_FOR_mrc2 = 407,
  CODE_FOR_mcrr = 408,
  CODE_FOR_mcrr2 = 409,
  CODE_FOR_mrrc = 410,
  CODE_FOR_mrrc2 = 411,
  CODE_FOR_tbcstv8qi = 412,
  CODE_FOR_tbcstv4hi = 413,
  CODE_FOR_tbcstv2si = 414,
  CODE_FOR_iwmmxt_iordi3 = 415,
  CODE_FOR_iwmmxt_xordi3 = 416,
  CODE_FOR_iwmmxt_anddi3 = 417,
  CODE_FOR_iwmmxt_nanddi3 = 418,
  CODE_FOR_movv2si_internal = 422,
  CODE_FOR_movv4hi_internal = 423,
  CODE_FOR_movv8qi_internal = 424,
  CODE_FOR_ssaddv8qi3 = 437,
  CODE_FOR_ssaddv4hi3 = 438,
  CODE_FOR_ssaddv2si3 = 439,
  CODE_FOR_usaddv8qi3 = 440,
  CODE_FOR_usaddv4hi3 = 441,
  CODE_FOR_usaddv2si3 = 442,
  CODE_FOR_sssubv8qi3 = 446,
  CODE_FOR_sssubv4hi3 = 447,
  CODE_FOR_sssubv2si3 = 448,
  CODE_FOR_ussubv8qi3 = 449,
  CODE_FOR_ussubv4hi3 = 450,
  CODE_FOR_ussubv2si3 = 451,
  CODE_FOR_smulv4hi3_highpart = 453,
  CODE_FOR_umulv4hi3_highpart = 454,
  CODE_FOR_iwmmxt_wmacs = 455,
  CODE_FOR_iwmmxt_wmacsz = 456,
  CODE_FOR_iwmmxt_wmacu = 457,
  CODE_FOR_iwmmxt_wmacuz = 458,
  CODE_FOR_iwmmxt_clrdi = 459,
  CODE_FOR_iwmmxt_clrv8qi = 460,
  CODE_FOR_iwmmxt_clrv4hi = 461,
  CODE_FOR_iwmmxt_clrv2si = 462,
  CODE_FOR_iwmmxt_uavgrndv8qi3 = 463,
  CODE_FOR_iwmmxt_uavgrndv4hi3 = 464,
  CODE_FOR_iwmmxt_uavgv8qi3 = 465,
  CODE_FOR_iwmmxt_uavgv4hi3 = 466,
  CODE_FOR_iwmmxt_tinsrb = 467,
  CODE_FOR_iwmmxt_tinsrh = 468,
  CODE_FOR_iwmmxt_tinsrw = 469,
  CODE_FOR_iwmmxt_textrmub = 470,
  CODE_FOR_iwmmxt_textrmsb = 471,
  CODE_FOR_iwmmxt_textrmuh = 472,
  CODE_FOR_iwmmxt_textrmsh = 473,
  CODE_FOR_iwmmxt_textrmw = 474,
  CODE_FOR_iwmmxt_wshufh = 475,
  CODE_FOR_eqv8qi3 = 476,
  CODE_FOR_eqv4hi3 = 477,
  CODE_FOR_eqv2si3 = 478,
  CODE_FOR_gtuv8qi3 = 479,
  CODE_FOR_gtuv4hi3 = 480,
  CODE_FOR_gtuv2si3 = 481,
  CODE_FOR_gtv8qi3 = 482,
  CODE_FOR_gtv4hi3 = 483,
  CODE_FOR_gtv2si3 = 484,
  CODE_FOR_iwmmxt_wpackhss = 497,
  CODE_FOR_iwmmxt_wpackwss = 498,
  CODE_FOR_iwmmxt_wpackdss = 499,
  CODE_FOR_iwmmxt_wpackhus = 500,
  CODE_FOR_iwmmxt_wpackwus = 501,
  CODE_FOR_iwmmxt_wpackdus = 502,
  CODE_FOR_iwmmxt_wunpckihb = 503,
  CODE_FOR_iwmmxt_wunpckihh = 504,
  CODE_FOR_iwmmxt_wunpckihw = 505,
  CODE_FOR_iwmmxt_wunpckilb = 506,
  CODE_FOR_iwmmxt_wunpckilh = 507,
  CODE_FOR_iwmmxt_wunpckilw = 508,
  CODE_FOR_iwmmxt_wunpckehub = 509,
  CODE_FOR_iwmmxt_wunpckehuh = 510,
  CODE_FOR_iwmmxt_wunpckehuw = 511,
  CODE_FOR_iwmmxt_wunpckehsb = 512,
  CODE_FOR_iwmmxt_wunpckehsh = 513,
  CODE_FOR_iwmmxt_wunpckehsw = 514,
  CODE_FOR_iwmmxt_wunpckelub = 515,
  CODE_FOR_iwmmxt_wunpckeluh = 516,
  CODE_FOR_iwmmxt_wunpckeluw = 517,
  CODE_FOR_iwmmxt_wunpckelsb = 518,
  CODE_FOR_iwmmxt_wunpckelsh = 519,
  CODE_FOR_iwmmxt_wunpckelsw = 520,
  CODE_FOR_rorv4hi3 = 521,
  CODE_FOR_rorv2si3 = 522,
  CODE_FOR_rordi3 = 523,
  CODE_FOR_ashrv4hi3_iwmmxt = 524,
  CODE_FOR_ashrv2si3_iwmmxt = 525,
  CODE_FOR_ashrdi3_iwmmxt = 526,
  CODE_FOR_lshrv4hi3_iwmmxt = 527,
  CODE_FOR_lshrv2si3_iwmmxt = 528,
  CODE_FOR_lshrdi3_iwmmxt = 529,
  CODE_FOR_ashlv4hi3_iwmmxt = 530,
  CODE_FOR_ashlv2si3_iwmmxt = 531,
  CODE_FOR_ashldi3_iwmmxt = 532,
  CODE_FOR_rorv4hi3_di = 533,
  CODE_FOR_rorv2si3_di = 534,
  CODE_FOR_rordi3_di = 535,
  CODE_FOR_ashrv4hi3_di = 536,
  CODE_FOR_ashrv2si3_di = 537,
  CODE_FOR_ashrdi3_di = 538,
  CODE_FOR_lshrv4hi3_di = 539,
  CODE_FOR_lshrv2si3_di = 540,
  CODE_FOR_lshrdi3_di = 541,
  CODE_FOR_ashlv4hi3_di = 542,
  CODE_FOR_ashlv2si3_di = 543,
  CODE_FOR_ashldi3_di = 544,
  CODE_FOR_iwmmxt_wmadds = 545,
  CODE_FOR_iwmmxt_wmaddu = 546,
  CODE_FOR_iwmmxt_tmia = 547,
  CODE_FOR_iwmmxt_tmiaph = 548,
  CODE_FOR_iwmmxt_tmiabb = 549,
  CODE_FOR_iwmmxt_tmiatb = 550,
  CODE_FOR_iwmmxt_tmiabt = 551,
  CODE_FOR_iwmmxt_tmiatt = 552,
  CODE_FOR_iwmmxt_tmovmskb = 553,
  CODE_FOR_iwmmxt_tmovmskh = 554,
  CODE_FOR_iwmmxt_tmovmskw = 555,
  CODE_FOR_iwmmxt_waccb = 556,
  CODE_FOR_iwmmxt_wacch = 557,
  CODE_FOR_iwmmxt_waccw = 558,
  CODE_FOR_iwmmxt_waligni = 559,
  CODE_FOR_iwmmxt_walignr = 560,
  CODE_FOR_iwmmxt_walignr0 = 561,
  CODE_FOR_iwmmxt_walignr1 = 562,
  CODE_FOR_iwmmxt_walignr2 = 563,
  CODE_FOR_iwmmxt_walignr3 = 564,
  CODE_FOR_iwmmxt_wsadb = 565,
  CODE_FOR_iwmmxt_wsadh = 566,
  CODE_FOR_iwmmxt_wsadbz = 567,
  CODE_FOR_iwmmxt_wsadhz = 568,
  CODE_FOR_iwmmxt_wabsv2si3 = 569,
  CODE_FOR_iwmmxt_wabsv4hi3 = 570,
  CODE_FOR_iwmmxt_wabsv8qi3 = 571,
  CODE_FOR_iwmmxt_wabsdiffb = 572,
  CODE_FOR_iwmmxt_wabsdiffh = 573,
  CODE_FOR_iwmmxt_wabsdiffw = 574,
  CODE_FOR_iwmmxt_waddsubhx = 575,
  CODE_FOR_iwmmxt_wsubaddhx = 576,
  CODE_FOR_addcv4hi3 = 577,
  CODE_FOR_addcv2si3 = 578,
  CODE_FOR_iwmmxt_avg4 = 579,
  CODE_FOR_iwmmxt_avg4r = 580,
  CODE_FOR_iwmmxt_wmaddsx = 581,
  CODE_FOR_iwmmxt_wmaddux = 582,
  CODE_FOR_iwmmxt_wmaddsn = 583,
  CODE_FOR_iwmmxt_wmaddun = 584,
  CODE_FOR_iwmmxt_wmulwsm = 585,
  CODE_FOR_iwmmxt_wmulwum = 586,
  CODE_FOR_iwmmxt_wmulsmr = 587,
  CODE_FOR_iwmmxt_wmulumr = 588,
  CODE_FOR_iwmmxt_wmulwsmr = 589,
  CODE_FOR_iwmmxt_wmulwumr = 590,
  CODE_FOR_iwmmxt_wmulwl = 591,
  CODE_FOR_iwmmxt_wqmulm = 592,
  CODE_FOR_iwmmxt_wqmulwm = 593,
  CODE_FOR_iwmmxt_wqmulmr = 594,
  CODE_FOR_iwmmxt_wqmulwmr = 595,
  CODE_FOR_iwmmxt_waddbhusm = 596,
  CODE_FOR_iwmmxt_waddbhusl = 597,
  CODE_FOR_iwmmxt_wqmiabb = 598,
  CODE_FOR_iwmmxt_wqmiabt = 599,
  CODE_FOR_iwmmxt_wqmiatb = 600,
  CODE_FOR_iwmmxt_wqmiatt = 601,
  CODE_FOR_iwmmxt_wqmiabbn = 602,
  CODE_FOR_iwmmxt_wqmiabtn = 603,
  CODE_FOR_iwmmxt_wqmiatbn = 604,
  CODE_FOR_iwmmxt_wqmiattn = 605,
  CODE_FOR_iwmmxt_wmiabb = 606,
  CODE_FOR_iwmmxt_wmiabt = 607,
  CODE_FOR_iwmmxt_wmiatb = 608,
  CODE_FOR_iwmmxt_wmiatt = 609,
  CODE_FOR_iwmmxt_wmiabbn = 610,
  CODE_FOR_iwmmxt_wmiabtn = 611,
  CODE_FOR_iwmmxt_wmiatbn = 612,
  CODE_FOR_iwmmxt_wmiattn = 613,
  CODE_FOR_iwmmxt_wmiawbb = 614,
  CODE_FOR_iwmmxt_wmiawbt = 615,
  CODE_FOR_iwmmxt_wmiawtb = 616,
  CODE_FOR_iwmmxt_wmiawtt = 617,
  CODE_FOR_iwmmxt_wmiawbbn = 618,
  CODE_FOR_iwmmxt_wmiawbtn = 619,
  CODE_FOR_iwmmxt_wmiawtbn = 620,
  CODE_FOR_iwmmxt_wmiawttn = 621,
  CODE_FOR_iwmmxt_wmerge = 622,
  CODE_FOR_iwmmxt_tandcv2si3 = 623,
  CODE_FOR_iwmmxt_tandcv4hi3 = 624,
  CODE_FOR_iwmmxt_tandcv8qi3 = 625,
  CODE_FOR_iwmmxt_torcv2si3 = 626,
  CODE_FOR_iwmmxt_torcv4hi3 = 627,
  CODE_FOR_iwmmxt_torcv8qi3 = 628,
  CODE_FOR_iwmmxt_torvscv2si3 = 629,
  CODE_FOR_iwmmxt_torvscv4hi3 = 630,
  CODE_FOR_iwmmxt_torvscv8qi3 = 631,
  CODE_FOR_iwmmxt_textrcv2si3 = 632,
  CODE_FOR_iwmmxt_textrcv4hi3 = 633,
  CODE_FOR_iwmmxt_textrcv8qi3 = 634,
  CODE_FOR_abshf2 = 657,
  CODE_FOR_neghf2 = 658,
  CODE_FOR_neon_vrndhf = 659,
  CODE_FOR_neon_vrndahf = 660,
  CODE_FOR_neon_vrndmhf = 661,
  CODE_FOR_neon_vrndnhf = 662,
  CODE_FOR_neon_vrndphf = 663,
  CODE_FOR_neon_vrndxhf = 664,
  CODE_FOR_neon_vrndihf = 665,
  CODE_FOR_addhf3 = 666,
  CODE_FOR_subhf3 = 669,
  CODE_FOR_divhf3 = 672,
  CODE_FOR_mulhf3 = 675,
  CODE_FOR_fmahf4 = 696,
  CODE_FOR_fmasf4 = 697,
  CODE_FOR_fmadf4 = 698,
  CODE_FOR_fmsubhf4_fp16 = 699,
  CODE_FOR_extendhfsf2 = 710,
  CODE_FOR_truncsfhf2 = 713,
  CODE_FOR_fixuns_truncsfsi2 = 716,
  CODE_FOR_fixuns_truncdfsi2 = 717,
  CODE_FOR_floatunssisf2 = 720,
  CODE_FOR_floatunssidf2 = 721,
  CODE_FOR_neon_vsqrthf = 722,
  CODE_FOR_neon_vrsqrtshf = 723,
  CODE_FOR_neon_vcvthshf = 740,
  CODE_FOR_neon_vcvthuhf = 741,
  CODE_FOR_neon_vcvthssi = 742,
  CODE_FOR_neon_vcvthusi = 743,
  CODE_FOR_neon_vcvths_nhf_unspec = 744,
  CODE_FOR_neon_vcvthu_nhf_unspec = 745,
  CODE_FOR_neon_vcvths_nsi_unspec = 746,
  CODE_FOR_neon_vcvthu_nsi_unspec = 747,
  CODE_FOR_neon_vcvtahssi = 748,
  CODE_FOR_neon_vcvtahusi = 749,
  CODE_FOR_neon_vcvtmhssi = 750,
  CODE_FOR_neon_vcvtmhusi = 751,
  CODE_FOR_neon_vcvtnhssi = 752,
  CODE_FOR_neon_vcvtnhusi = 753,
  CODE_FOR_neon_vcvtphssi = 754,
  CODE_FOR_neon_vcvtphusi = 755,
  CODE_FOR_btruncsf2 = 757,
  CODE_FOR_ceilsf2 = 758,
  CODE_FOR_floorsf2 = 759,
  CODE_FOR_nearbyintsf2 = 760,
  CODE_FOR_rintsf2 = 761,
  CODE_FOR_roundsf2 = 762,
  CODE_FOR_btruncdf2 = 763,
  CODE_FOR_ceildf2 = 764,
  CODE_FOR_floordf2 = 765,
  CODE_FOR_nearbyintdf2 = 766,
  CODE_FOR_rintdf2 = 767,
  CODE_FOR_rounddf2 = 768,
  CODE_FOR_lceilsfsi2 = 769,
  CODE_FOR_lfloorsfsi2 = 770,
  CODE_FOR_lroundsfsi2 = 771,
  CODE_FOR_lceilusfsi2 = 772,
  CODE_FOR_lfloorusfsi2 = 773,
  CODE_FOR_lroundusfsi2 = 774,
  CODE_FOR_lceildfsi2 = 775,
  CODE_FOR_lfloordfsi2 = 776,
  CODE_FOR_lrounddfsi2 = 777,
  CODE_FOR_lceiludfsi2 = 778,
  CODE_FOR_lfloorudfsi2 = 779,
  CODE_FOR_lroundudfsi2 = 780,
  CODE_FOR_smaxsf3 = 781,
  CODE_FOR_smaxdf3 = 782,
  CODE_FOR_sminsf3 = 783,
  CODE_FOR_smindf3 = 784,
  CODE_FOR_neon_vmaxnmhf = 785,
  CODE_FOR_neon_vminnmhf = 786,
  CODE_FOR_fmaxsf3 = 787,
  CODE_FOR_fminsf3 = 788,
  CODE_FOR_fmaxdf3 = 789,
  CODE_FOR_fmindf3 = 790,
  CODE_FOR_set_fpscr = 791,
  CODE_FOR_get_fpscr = 792,
  CODE_FOR_no_literal_pool_df_immediate = 793,
  CODE_FOR_no_literal_pool_sf_immediate = 794,
  CODE_FOR_thumb1_subsi3_insn = 798,
  CODE_FOR_thumb1_bicsi3 = 802,
  CODE_FOR_thumb1_extendhisi2 = 817,
  CODE_FOR_thumb1_extendqisi2 = 818,
  CODE_FOR_movmem12b = 826,
  CODE_FOR_movmem8b = 827,
  CODE_FOR_thumb1_cbz = 828,
  CODE_FOR_cbranchsi4_insn = 829,
  CODE_FOR_cbranchsi4_scratch = 830,
  CODE_FOR_cstoresi_nltu_thumb1 = 841,
  CODE_FOR_cstoresi_ltu_thumb1 = 842,
  CODE_FOR_thumb1_addsi3_addgeu = 843,
  CODE_FOR_thumb1_casesi_dispatch = 853,
  CODE_FOR_prologue_thumb1_interwork = 855,
  CODE_FOR_thumb_eh_return = 859,
  CODE_FOR_tls_load_dot_plus_four = 869,
  CODE_FOR_thumb2_zero_extendqisi2_v6 = 896,
  CODE_FOR_thumb2_casesi_internal = 897,
  CODE_FOR_thumb2_casesi_internal_pic = 898,
  CODE_FOR_thumb2_eh_return = 901,
  CODE_FOR_thumb2_addsi3_compare0 = 909,
  CODE_FOR_vec_setv8qi_internal = 965,
  CODE_FOR_vec_setv4hi_internal = 966,
  CODE_FOR_vec_setv4hf_internal = 967,
  CODE_FOR_vec_setv2si_internal = 968,
  CODE_FOR_vec_setv2sf_internal = 969,
  CODE_FOR_vec_setv16qi_internal = 970,
  CODE_FOR_vec_setv8hi_internal = 971,
  CODE_FOR_vec_setv8hf_internal = 972,
  CODE_FOR_vec_setv4si_internal = 973,
  CODE_FOR_vec_setv4sf_internal = 974,
  CODE_FOR_vec_setv2di_internal = 975,
  CODE_FOR_vec_extractv8qiqi = 976,
  CODE_FOR_vec_extractv4hihi = 977,
  CODE_FOR_vec_extractv4hfhf = 978,
  CODE_FOR_vec_extractv2sisi = 979,
  CODE_FOR_vec_extractv2sfsf = 980,
  CODE_FOR_vec_extractv16qiqi = 981,
  CODE_FOR_vec_extractv8hihi = 982,
  CODE_FOR_vec_extractv8hfhf = 983,
  CODE_FOR_vec_extractv4sisi = 984,
  CODE_FOR_vec_extractv4sfsf = 985,
  CODE_FOR_vec_extractv2didi = 986,
  CODE_FOR_addv8hf3 = 998,
  CODE_FOR_addv4hf3 = 999,
  CODE_FOR_addv8hf3_fp16 = 1000,
  CODE_FOR_addv4hf3_fp16 = 1001,
  CODE_FOR_adddi3_neon = 1002,
  CODE_FOR_subv8hf3 = 1014,
  CODE_FOR_subv4hf3 = 1015,
  CODE_FOR_subv8hf3_fp16 = 1016,
  CODE_FOR_subv4hf3_fp16 = 1017,
  CODE_FOR_subdi3_neon = 1018,
  CODE_FOR_mulv8qi3addv8qi_neon = 1027,
  CODE_FOR_mulv16qi3addv16qi_neon = 1028,
  CODE_FOR_mulv4hi3addv4hi_neon = 1029,
  CODE_FOR_mulv8hi3addv8hi_neon = 1030,
  CODE_FOR_mulv2si3addv2si_neon = 1031,
  CODE_FOR_mulv4si3addv4si_neon = 1032,
  CODE_FOR_mulv2sf3addv2sf_neon = 1033,
  CODE_FOR_mulv4sf3addv4sf_neon = 1034,
  CODE_FOR_mulv8hf3addv8hf_neon = 1035,
  CODE_FOR_mulv4hf3addv4hf_neon = 1036,
  CODE_FOR_mulv8qi3negv8qiaddv8qi_neon = 1037,
  CODE_FOR_mulv16qi3negv16qiaddv16qi_neon = 1038,
  CODE_FOR_mulv4hi3negv4hiaddv4hi_neon = 1039,
  CODE_FOR_mulv8hi3negv8hiaddv8hi_neon = 1040,
  CODE_FOR_mulv2si3negv2siaddv2si_neon = 1041,
  CODE_FOR_mulv4si3negv4siaddv4si_neon = 1042,
  CODE_FOR_mulv2sf3negv2sfaddv2sf_neon = 1043,
  CODE_FOR_mulv4sf3negv4sfaddv4sf_neon = 1044,
  CODE_FOR_fmav2sf4 = 1045,
  CODE_FOR_fmav4sf4 = 1046,
  CODE_FOR_fmav2sf4_intrinsic = 1047,
  CODE_FOR_fmav4sf4_intrinsic = 1048,
  CODE_FOR_fmav8hf4 = 1049,
  CODE_FOR_fmav4hf4 = 1050,
  CODE_FOR_fmav8hf4_intrinsic = 1051,
  CODE_FOR_fmav4hf4_intrinsic = 1052,
  CODE_FOR_fmsubv2sf4_intrinsic = 1055,
  CODE_FOR_fmsubv4sf4_intrinsic = 1056,
  CODE_FOR_fmsubv8hf4_intrinsic = 1057,
  CODE_FOR_fmsubv4hf4_intrinsic = 1058,
  CODE_FOR_neon_vrintpv2sf = 1059,
  CODE_FOR_neon_vrintzv2sf = 1060,
  CODE_FOR_neon_vrintmv2sf = 1061,
  CODE_FOR_neon_vrintxv2sf = 1062,
  CODE_FOR_neon_vrintav2sf = 1063,
  CODE_FOR_neon_vrintnv2sf = 1064,
  CODE_FOR_neon_vrintpv4sf = 1065,
  CODE_FOR_neon_vrintzv4sf = 1066,
  CODE_FOR_neon_vrintmv4sf = 1067,
  CODE_FOR_neon_vrintxv4sf = 1068,
  CODE_FOR_neon_vrintav4sf = 1069,
  CODE_FOR_neon_vrintnv4sf = 1070,
  CODE_FOR_neon_vcvtpv2sfv2si = 1071,
  CODE_FOR_neon_vcvtmv2sfv2si = 1072,
  CODE_FOR_neon_vcvtav2sfv2si = 1073,
  CODE_FOR_neon_vcvtpuv2sfv2si = 1074,
  CODE_FOR_neon_vcvtmuv2sfv2si = 1075,
  CODE_FOR_neon_vcvtauv2sfv2si = 1076,
  CODE_FOR_neon_vcvtpv4sfv4si = 1077,
  CODE_FOR_neon_vcvtmv4sfv4si = 1078,
  CODE_FOR_neon_vcvtav4sfv4si = 1079,
  CODE_FOR_neon_vcvtpuv4sfv4si = 1080,
  CODE_FOR_neon_vcvtmuv4sfv4si = 1081,
  CODE_FOR_neon_vcvtauv4sfv4si = 1082,
  CODE_FOR_iorv8qi3 = 1083,
  CODE_FOR_iorv16qi3 = 1084,
  CODE_FOR_iorv4hi3 = 1085,
  CODE_FOR_iorv8hi3 = 1086,
  CODE_FOR_iorv2si3 = 1087,
  CODE_FOR_iorv4si3 = 1088,
  CODE_FOR_iorv4hf3 = 1089,
  CODE_FOR_iorv8hf3 = 1090,
  CODE_FOR_iorv2sf3 = 1091,
  CODE_FOR_iorv4sf3 = 1092,
  CODE_FOR_iorv2di3 = 1093,
  CODE_FOR_andv8qi3 = 1094,
  CODE_FOR_andv16qi3 = 1095,
  CODE_FOR_andv4hi3 = 1096,
  CODE_FOR_andv8hi3 = 1097,
  CODE_FOR_andv2si3 = 1098,
  CODE_FOR_andv4si3 = 1099,
  CODE_FOR_andv4hf3 = 1100,
  CODE_FOR_andv8hf3 = 1101,
  CODE_FOR_andv2sf3 = 1102,
  CODE_FOR_andv4sf3 = 1103,
  CODE_FOR_andv2di3 = 1104,
  CODE_FOR_ornv8qi3_neon = 1105,
  CODE_FOR_ornv16qi3_neon = 1106,
  CODE_FOR_ornv4hi3_neon = 1107,
  CODE_FOR_ornv8hi3_neon = 1108,
  CODE_FOR_ornv2si3_neon = 1109,
  CODE_FOR_ornv4si3_neon = 1110,
  CODE_FOR_ornv4hf3_neon = 1111,
  CODE_FOR_ornv8hf3_neon = 1112,
  CODE_FOR_ornv2sf3_neon = 1113,
  CODE_FOR_ornv4sf3_neon = 1114,
  CODE_FOR_ornv2di3_neon = 1115,
  CODE_FOR_orndi3_neon = 1116,
  CODE_FOR_bicv8qi3_neon = 1117,
  CODE_FOR_bicv16qi3_neon = 1118,
  CODE_FOR_bicv4hi3_neon = 1119,
  CODE_FOR_bicv8hi3_neon = 1120,
  CODE_FOR_bicv2si3_neon = 1121,
  CODE_FOR_bicv4si3_neon = 1122,
  CODE_FOR_bicv4hf3_neon = 1123,
  CODE_FOR_bicv8hf3_neon = 1124,
  CODE_FOR_bicv2sf3_neon = 1125,
  CODE_FOR_bicv4sf3_neon = 1126,
  CODE_FOR_bicv2di3_neon = 1127,
  CODE_FOR_bicdi3_neon = 1128,
  CODE_FOR_xorv8qi3 = 1129,
  CODE_FOR_xorv16qi3 = 1130,
  CODE_FOR_xorv4hi3 = 1131,
  CODE_FOR_xorv8hi3 = 1132,
  CODE_FOR_xorv2si3 = 1133,
  CODE_FOR_xorv4si3 = 1134,
  CODE_FOR_xorv4hf3 = 1135,
  CODE_FOR_xorv8hf3 = 1136,
  CODE_FOR_xorv2sf3 = 1137,
  CODE_FOR_xorv4sf3 = 1138,
  CODE_FOR_xorv2di3 = 1139,
  CODE_FOR_one_cmplv8qi2 = 1140,
  CODE_FOR_one_cmplv16qi2 = 1141,
  CODE_FOR_one_cmplv4hi2 = 1142,
  CODE_FOR_one_cmplv8hi2 = 1143,
  CODE_FOR_one_cmplv2si2 = 1144,
  CODE_FOR_one_cmplv4si2 = 1145,
  CODE_FOR_one_cmplv4hf2 = 1146,
  CODE_FOR_one_cmplv8hf2 = 1147,
  CODE_FOR_one_cmplv2sf2 = 1148,
  CODE_FOR_one_cmplv4sf2 = 1149,
  CODE_FOR_one_cmplv2di2 = 1150,
  CODE_FOR_absv8qi2 = 1151,
  CODE_FOR_absv16qi2 = 1152,
  CODE_FOR_absv4hi2 = 1153,
  CODE_FOR_absv8hi2 = 1154,
  CODE_FOR_absv2si2 = 1155,
  CODE_FOR_absv4si2 = 1156,
  CODE_FOR_absv2sf2 = 1157,
  CODE_FOR_absv4sf2 = 1158,
  CODE_FOR_negv8qi2 = 1159,
  CODE_FOR_negv16qi2 = 1160,
  CODE_FOR_negv4hi2 = 1161,
  CODE_FOR_negv8hi2 = 1162,
  CODE_FOR_negv2si2 = 1163,
  CODE_FOR_negv4si2 = 1164,
  CODE_FOR_negv2sf2 = 1165,
  CODE_FOR_negv4sf2 = 1166,
  CODE_FOR_negdi2_neon = 1167,
  CODE_FOR_absv8hf2 = 1168,
  CODE_FOR_negv8hf2 = 1169,
  CODE_FOR_absv4hf2 = 1170,
  CODE_FOR_negv4hf2 = 1171,
  CODE_FOR_neon_vrndv8hf = 1172,
  CODE_FOR_neon_vrndav8hf = 1173,
  CODE_FOR_neon_vrndmv8hf = 1174,
  CODE_FOR_neon_vrndnv8hf = 1175,
  CODE_FOR_neon_vrndpv8hf = 1176,
  CODE_FOR_neon_vrndxv8hf = 1177,
  CODE_FOR_neon_vrndv4hf = 1178,
  CODE_FOR_neon_vrndav4hf = 1179,
  CODE_FOR_neon_vrndmv4hf = 1180,
  CODE_FOR_neon_vrndnv4hf = 1181,
  CODE_FOR_neon_vrndpv4hf = 1182,
  CODE_FOR_neon_vrndxv4hf = 1183,
  CODE_FOR_neon_vrsqrtev8hf = 1184,
  CODE_FOR_neon_vrsqrtev4hf = 1185,
  CODE_FOR_vashlv8qi3 = 1214,
  CODE_FOR_vashlv16qi3 = 1215,
  CODE_FOR_vashlv4hi3 = 1216,
  CODE_FOR_vashlv8hi3 = 1217,
  CODE_FOR_vashlv2si3 = 1218,
  CODE_FOR_vashlv4si3 = 1219,
  CODE_FOR_vashrv8qi3_imm = 1220,
  CODE_FOR_vashrv16qi3_imm = 1221,
  CODE_FOR_vashrv4hi3_imm = 1222,
  CODE_FOR_vashrv8hi3_imm = 1223,
  CODE_FOR_vashrv2si3_imm = 1224,
  CODE_FOR_vashrv4si3_imm = 1225,
  CODE_FOR_vlshrv8qi3_imm = 1226,
  CODE_FOR_vlshrv16qi3_imm = 1227,
  CODE_FOR_vlshrv4hi3_imm = 1228,
  CODE_FOR_vlshrv8hi3_imm = 1229,
  CODE_FOR_vlshrv2si3_imm = 1230,
  CODE_FOR_vlshrv4si3_imm = 1231,
  CODE_FOR_ashlv8qi3_signed = 1232,
  CODE_FOR_ashlv16qi3_signed = 1233,
  CODE_FOR_ashlv4hi3_signed = 1234,
  CODE_FOR_ashlv8hi3_signed = 1235,
  CODE_FOR_ashlv2si3_signed = 1236,
  CODE_FOR_ashlv4si3_signed = 1237,
  CODE_FOR_ashlv2di3_signed = 1238,
  CODE_FOR_ashlv8qi3_unsigned = 1239,
  CODE_FOR_ashlv16qi3_unsigned = 1240,
  CODE_FOR_ashlv4hi3_unsigned = 1241,
  CODE_FOR_ashlv8hi3_unsigned = 1242,
  CODE_FOR_ashlv2si3_unsigned = 1243,
  CODE_FOR_ashlv4si3_unsigned = 1244,
  CODE_FOR_ashlv2di3_unsigned = 1245,
  CODE_FOR_neon_load_count = 1246,
  CODE_FOR_ashldi3_neon_noclobber = 1247,
  CODE_FOR_ashldi3_neon = 1248,
  CODE_FOR_signed_shift_di3_neon = 1249,
  CODE_FOR_unsigned_shift_di3_neon = 1250,
  CODE_FOR_ashrdi3_neon_imm_noclobber = 1251,
  CODE_FOR_lshrdi3_neon_imm_noclobber = 1252,
  CODE_FOR_ashrdi3_neon = 1253,
  CODE_FOR_lshrdi3_neon = 1254,
  CODE_FOR_vec_sel_widen_ssum_lov16qiv8qi3 = 1255,
  CODE_FOR_vec_sel_widen_ssum_lov8hiv4hi3 = 1256,
  CODE_FOR_vec_sel_widen_ssum_lov4siv2si3 = 1257,
  CODE_FOR_vec_sel_widen_ssum_hiv16qiv8qi3 = 1258,
  CODE_FOR_vec_sel_widen_ssum_hiv8hiv4hi3 = 1259,
  CODE_FOR_vec_sel_widen_ssum_hiv4siv2si3 = 1260,
  CODE_FOR_widen_ssumv8qi3 = 1261,
  CODE_FOR_widen_ssumv4hi3 = 1262,
  CODE_FOR_widen_ssumv2si3 = 1263,
  CODE_FOR_vec_sel_widen_usum_lov16qiv8qi3 = 1264,
  CODE_FOR_vec_sel_widen_usum_lov8hiv4hi3 = 1265,
  CODE_FOR_vec_sel_widen_usum_lov4siv2si3 = 1266,
  CODE_FOR_vec_sel_widen_usum_hiv16qiv8qi3 = 1267,
  CODE_FOR_vec_sel_widen_usum_hiv8hiv4hi3 = 1268,
  CODE_FOR_vec_sel_widen_usum_hiv4siv2si3 = 1269,
  CODE_FOR_widen_usumv8qi3 = 1270,
  CODE_FOR_widen_usumv4hi3 = 1271,
  CODE_FOR_widen_usumv2si3 = 1272,
  CODE_FOR_quad_halves_plusv4si = 1273,
  CODE_FOR_quad_halves_sminv4si = 1274,
  CODE_FOR_quad_halves_smaxv4si = 1275,
  CODE_FOR_quad_halves_uminv4si = 1276,
  CODE_FOR_quad_halves_umaxv4si = 1277,
  CODE_FOR_quad_halves_plusv4sf = 1278,
  CODE_FOR_quad_halves_sminv4sf = 1279,
  CODE_FOR_quad_halves_smaxv4sf = 1280,
  CODE_FOR_quad_halves_plusv8hi = 1281,
  CODE_FOR_quad_halves_sminv8hi = 1282,
  CODE_FOR_quad_halves_smaxv8hi = 1283,
  CODE_FOR_quad_halves_uminv8hi = 1284,
  CODE_FOR_quad_halves_umaxv8hi = 1285,
  CODE_FOR_quad_halves_plusv16qi = 1286,
  CODE_FOR_quad_halves_sminv16qi = 1287,
  CODE_FOR_quad_halves_smaxv16qi = 1288,
  CODE_FOR_quad_halves_uminv16qi = 1289,
  CODE_FOR_quad_halves_umaxv16qi = 1290,
  CODE_FOR_arm_reduc_plus_internal_v2di = 1291,
  CODE_FOR_neon_vpadd_internalv8qi = 1292,
  CODE_FOR_neon_vpadd_internalv4hi = 1293,
  CODE_FOR_neon_vpadd_internalv2si = 1294,
  CODE_FOR_neon_vpadd_internalv2sf = 1295,
  CODE_FOR_neon_vpaddv4hf = 1296,
  CODE_FOR_neon_vpsminv8qi = 1297,
  CODE_FOR_neon_vpsminv4hi = 1298,
  CODE_FOR_neon_vpsminv2si = 1299,
  CODE_FOR_neon_vpsminv2sf = 1300,
  CODE_FOR_neon_vpsmaxv8qi = 1301,
  CODE_FOR_neon_vpsmaxv4hi = 1302,
  CODE_FOR_neon_vpsmaxv2si = 1303,
  CODE_FOR_neon_vpsmaxv2sf = 1304,
  CODE_FOR_neon_vpuminv8qi = 1305,
  CODE_FOR_neon_vpuminv4hi = 1306,
  CODE_FOR_neon_vpuminv2si = 1307,
  CODE_FOR_neon_vpumaxv8qi = 1308,
  CODE_FOR_neon_vpumaxv4hi = 1309,
  CODE_FOR_neon_vpumaxv2si = 1310,
  CODE_FOR_neon_vaddv2sf_unspec = 1327,
  CODE_FOR_neon_vaddv4sf_unspec = 1328,
  CODE_FOR_neon_vaddlsv8qi = 1329,
  CODE_FOR_neon_vaddluv8qi = 1330,
  CODE_FOR_neon_vaddlsv4hi = 1331,
  CODE_FOR_neon_vaddluv4hi = 1332,
  CODE_FOR_neon_vaddlsv2si = 1333,
  CODE_FOR_neon_vaddluv2si = 1334,
  CODE_FOR_neon_vaddwsv8qi = 1335,
  CODE_FOR_neon_vaddwuv8qi = 1336,
  CODE_FOR_neon_vaddwsv4hi = 1337,
  CODE_FOR_neon_vaddwuv4hi = 1338,
  CODE_FOR_neon_vaddwsv2si = 1339,
  CODE_FOR_neon_vaddwuv2si = 1340,
  CODE_FOR_neon_vrhaddsv8qi = 1341,
  CODE_FOR_neon_vrhadduv8qi = 1342,
  CODE_FOR_neon_vhaddsv8qi = 1343,
  CODE_FOR_neon_vhadduv8qi = 1344,
  CODE_FOR_neon_vrhaddsv16qi = 1345,
  CODE_FOR_neon_vrhadduv16qi = 1346,
  CODE_FOR_neon_vhaddsv16qi = 1347,
  CODE_FOR_neon_vhadduv16qi = 1348,
  CODE_FOR_neon_vrhaddsv4hi = 1349,
  CODE_FOR_neon_vrhadduv4hi = 1350,
  CODE_FOR_neon_vhaddsv4hi = 1351,
  CODE_FOR_neon_vhadduv4hi = 1352,
  CODE_FOR_neon_vrhaddsv8hi = 1353,
  CODE_FOR_neon_vrhadduv8hi = 1354,
  CODE_FOR_neon_vhaddsv8hi = 1355,
  CODE_FOR_neon_vhadduv8hi = 1356,
  CODE_FOR_neon_vrhaddsv2si = 1357,
  CODE_FOR_neon_vrhadduv2si = 1358,
  CODE_FOR_neon_vhaddsv2si = 1359,
  CODE_FOR_neon_vhadduv2si = 1360,
  CODE_FOR_neon_vrhaddsv4si = 1361,
  CODE_FOR_neon_vrhadduv4si = 1362,
  CODE_FOR_neon_vhaddsv4si = 1363,
  CODE_FOR_neon_vhadduv4si = 1364,
  CODE_FOR_neon_vqaddsv8qi = 1365,
  CODE_FOR_neon_vqadduv8qi = 1366,
  CODE_FOR_neon_vqaddsv16qi = 1367,
  CODE_FOR_neon_vqadduv16qi = 1368,
  CODE_FOR_neon_vqaddsv4hi = 1369,
  CODE_FOR_neon_vqadduv4hi = 1370,
  CODE_FOR_neon_vqaddsv8hi = 1371,
  CODE_FOR_neon_vqadduv8hi = 1372,
  CODE_FOR_neon_vqaddsv2si = 1373,
  CODE_FOR_neon_vqadduv2si = 1374,
  CODE_FOR_neon_vqaddsv4si = 1375,
  CODE_FOR_neon_vqadduv4si = 1376,
  CODE_FOR_neon_vqaddsdi = 1377,
  CODE_FOR_neon_vqaddudi = 1378,
  CODE_FOR_neon_vqaddsv2di = 1379,
  CODE_FOR_neon_vqadduv2di = 1380,
  CODE_FOR_neon_vaddhnv8hi = 1381,
  CODE_FOR_neon_vraddhnv8hi = 1382,
  CODE_FOR_neon_vaddhnv4si = 1383,
  CODE_FOR_neon_vraddhnv4si = 1384,
  CODE_FOR_neon_vaddhnv2di = 1385,
  CODE_FOR_neon_vraddhnv2di = 1386,
  CODE_FOR_neon_vmulpv8qi = 1387,
  CODE_FOR_neon_vmulpv16qi = 1388,
  CODE_FOR_neon_vmulfv2sf = 1389,
  CODE_FOR_neon_vmulfv4sf = 1390,
  CODE_FOR_mulv8hf3 = 1391,
  CODE_FOR_mulv4hf3 = 1392,
  CODE_FOR_neon_vmulfv8hf = 1393,
  CODE_FOR_neon_vmulfv4hf = 1394,
  CODE_FOR_vfmal_lowv2sf_intrinsic = 1395,
  CODE_FOR_vfmal_lowv4sf_intrinsic = 1396,
  CODE_FOR_vfmsl_highv2sf_intrinsic = 1397,
  CODE_FOR_vfmsl_highv4sf_intrinsic = 1398,
  CODE_FOR_vfmal_highv2sf_intrinsic = 1399,
  CODE_FOR_vfmal_highv4sf_intrinsic = 1400,
  CODE_FOR_vfmsl_lowv2sf_intrinsic = 1401,
  CODE_FOR_vfmsl_lowv4sf_intrinsic = 1402,
  CODE_FOR_vfmal_lane_lowv2sf_intrinsic = 1403,
  CODE_FOR_vfmal_lane_lowv4sf_intrinsic = 1404,
  CODE_FOR_vfmal_lane_lowv8hfv2sf_intrinsic = 1405,
  CODE_FOR_vfmal_lane_lowv4hfv4sf_intrinsic = 1406,
  CODE_FOR_vfmal_lane_highv8hfv2sf_intrinsic = 1407,
  CODE_FOR_vfmal_lane_highv4hfv4sf_intrinsic = 1408,
  CODE_FOR_vfmal_lane_highv2sf_intrinsic = 1409,
  CODE_FOR_vfmal_lane_highv4sf_intrinsic = 1410,
  CODE_FOR_vfmsl_lane_lowv2sf_intrinsic = 1411,
  CODE_FOR_vfmsl_lane_lowv4sf_intrinsic = 1412,
  CODE_FOR_vfmsl_lane_lowv8hfv2sf_intrinsic = 1413,
  CODE_FOR_vfmsl_lane_lowv4hfv4sf_intrinsic = 1414,
  CODE_FOR_vfmsl_lane_highv8hfv2sf_intrinsic = 1415,
  CODE_FOR_vfmsl_lane_highv4hfv4sf_intrinsic = 1416,
  CODE_FOR_vfmsl_lane_highv2sf_intrinsic = 1417,
  CODE_FOR_vfmsl_lane_highv4sf_intrinsic = 1418,
  CODE_FOR_neon_vmlav8qi_unspec = 1419,
  CODE_FOR_neon_vmlav16qi_unspec = 1420,
  CODE_FOR_neon_vmlav4hi_unspec = 1421,
  CODE_FOR_neon_vmlav8hi_unspec = 1422,
  CODE_FOR_neon_vmlav2si_unspec = 1423,
  CODE_FOR_neon_vmlav4si_unspec = 1424,
  CODE_FOR_neon_vmlav2sf_unspec = 1425,
  CODE_FOR_neon_vmlav4sf_unspec = 1426,
  CODE_FOR_neon_vmlalsv8qi = 1427,
  CODE_FOR_neon_vmlaluv8qi = 1428,
  CODE_FOR_neon_vmlalsv4hi = 1429,
  CODE_FOR_neon_vmlaluv4hi = 1430,
  CODE_FOR_neon_vmlalsv2si = 1431,
  CODE_FOR_neon_vmlaluv2si = 1432,
  CODE_FOR_neon_vmlsv8qi_unspec = 1433,
  CODE_FOR_neon_vmlsv16qi_unspec = 1434,
  CODE_FOR_neon_vmlsv4hi_unspec = 1435,
  CODE_FOR_neon_vmlsv8hi_unspec = 1436,
  CODE_FOR_neon_vmlsv2si_unspec = 1437,
  CODE_FOR_neon_vmlsv4si_unspec = 1438,
  CODE_FOR_neon_vmlsv2sf_unspec = 1439,
  CODE_FOR_neon_vmlsv4sf_unspec = 1440,
  CODE_FOR_neon_vmlslsv8qi = 1441,
  CODE_FOR_neon_vmlsluv8qi = 1442,
  CODE_FOR_neon_vmlslsv4hi = 1443,
  CODE_FOR_neon_vmlsluv4hi = 1444,
  CODE_FOR_neon_vmlslsv2si = 1445,
  CODE_FOR_neon_vmlsluv2si = 1446,
  CODE_FOR_neon_vqdmulhv4hi = 1447,
  CODE_FOR_neon_vqrdmulhv4hi = 1448,
  CODE_FOR_neon_vqdmulhv2si = 1449,
  CODE_FOR_neon_vqrdmulhv2si = 1450,
  CODE_FOR_neon_vqdmulhv8hi = 1451,
  CODE_FOR_neon_vqrdmulhv8hi = 1452,
  CODE_FOR_neon_vqdmulhv4si = 1453,
  CODE_FOR_neon_vqrdmulhv4si = 1454,
  CODE_FOR_neon_vqrdmlahv4hi = 1455,
  CODE_FOR_neon_vqrdmlshv4hi = 1456,
  CODE_FOR_neon_vqrdmlahv2si = 1457,
  CODE_FOR_neon_vqrdmlshv2si = 1458,
  CODE_FOR_neon_vqrdmlahv8hi = 1459,
  CODE_FOR_neon_vqrdmlshv8hi = 1460,
  CODE_FOR_neon_vqrdmlahv4si = 1461,
  CODE_FOR_neon_vqrdmlshv4si = 1462,
  CODE_FOR_neon_vqdmlalv4hi = 1463,
  CODE_FOR_neon_vqdmlalv2si = 1464,
  CODE_FOR_neon_vqdmlslv4hi = 1465,
  CODE_FOR_neon_vqdmlslv2si = 1466,
  CODE_FOR_neon_vmullsv8qi = 1467,
  CODE_FOR_neon_vmulluv8qi = 1468,
  CODE_FOR_neon_vmullpv8qi = 1469,
  CODE_FOR_neon_vmullsv4hi = 1470,
  CODE_FOR_neon_vmulluv4hi = 1471,
  CODE_FOR_neon_vmullpv4hi = 1472,
  CODE_FOR_neon_vmullsv2si = 1473,
  CODE_FOR_neon_vmulluv2si = 1474,
  CODE_FOR_neon_vmullpv2si = 1475,
  CODE_FOR_neon_vqdmullv4hi = 1476,
  CODE_FOR_neon_vqdmullv2si = 1477,
  CODE_FOR_neon_vsubv2sf_unspec = 1478,
  CODE_FOR_neon_vsubv4sf_unspec = 1479,
  CODE_FOR_neon_vsublsv8qi = 1480,
  CODE_FOR_neon_vsubluv8qi = 1481,
  CODE_FOR_neon_vsublsv4hi = 1482,
  CODE_FOR_neon_vsubluv4hi = 1483,
  CODE_FOR_neon_vsublsv2si = 1484,
  CODE_FOR_neon_vsubluv2si = 1485,
  CODE_FOR_neon_vsubwsv8qi = 1486,
  CODE_FOR_neon_vsubwuv8qi = 1487,
  CODE_FOR_neon_vsubwsv4hi = 1488,
  CODE_FOR_neon_vsubwuv4hi = 1489,
  CODE_FOR_neon_vsubwsv2si = 1490,
  CODE_FOR_neon_vsubwuv2si = 1491,
  CODE_FOR_neon_vqsubsv8qi = 1492,
  CODE_FOR_neon_vqsubuv8qi = 1493,
  CODE_FOR_neon_vqsubsv16qi = 1494,
  CODE_FOR_neon_vqsubuv16qi = 1495,
  CODE_FOR_neon_vqsubsv4hi = 1496,
  CODE_FOR_neon_vqsubuv4hi = 1497,
  CODE_FOR_neon_vqsubsv8hi = 1498,
  CODE_FOR_neon_vqsubuv8hi = 1499,
  CODE_FOR_neon_vqsubsv2si = 1500,
  CODE_FOR_neon_vqsubuv2si = 1501,
  CODE_FOR_neon_vqsubsv4si = 1502,
  CODE_FOR_neon_vqsubuv4si = 1503,
  CODE_FOR_neon_vqsubsdi = 1504,
  CODE_FOR_neon_vqsubudi = 1505,
  CODE_FOR_neon_vqsubsv2di = 1506,
  CODE_FOR_neon_vqsubuv2di = 1507,
  CODE_FOR_neon_vhsubsv8qi = 1508,
  CODE_FOR_neon_vhsubuv8qi = 1509,
  CODE_FOR_neon_vhsubsv16qi = 1510,
  CODE_FOR_neon_vhsubuv16qi = 1511,
  CODE_FOR_neon_vhsubsv4hi = 1512,
  CODE_FOR_neon_vhsubuv4hi = 1513,
  CODE_FOR_neon_vhsubsv8hi = 1514,
  CODE_FOR_neon_vhsubuv8hi = 1515,
  CODE_FOR_neon_vhsubsv2si = 1516,
  CODE_FOR_neon_vhsubuv2si = 1517,
  CODE_FOR_neon_vhsubsv4si = 1518,
  CODE_FOR_neon_vhsubuv4si = 1519,
  CODE_FOR_neon_vsubhnv8hi = 1520,
  CODE_FOR_neon_vrsubhnv8hi = 1521,
  CODE_FOR_neon_vsubhnv4si = 1522,
  CODE_FOR_neon_vrsubhnv4si = 1523,
  CODE_FOR_neon_vsubhnv2di = 1524,
  CODE_FOR_neon_vrsubhnv2di = 1525,
  CODE_FOR_neon_vceqv8qi_insn = 1526,
  CODE_FOR_neon_vcgtv8qi_insn = 1527,
  CODE_FOR_neon_vcgev8qi_insn = 1528,
  CODE_FOR_neon_vclev8qi_insn = 1529,
  CODE_FOR_neon_vcltv8qi_insn = 1530,
  CODE_FOR_neon_vceqv16qi_insn = 1531,
  CODE_FOR_neon_vcgtv16qi_insn = 1532,
  CODE_FOR_neon_vcgev16qi_insn = 1533,
  CODE_FOR_neon_vclev16qi_insn = 1534,
  CODE_FOR_neon_vcltv16qi_insn = 1535,
  CODE_FOR_neon_vceqv4hi_insn = 1536,
  CODE_FOR_neon_vcgtv4hi_insn = 1537,
  CODE_FOR_neon_vcgev4hi_insn = 1538,
  CODE_FOR_neon_vclev4hi_insn = 1539,
  CODE_FOR_neon_vcltv4hi_insn = 1540,
  CODE_FOR_neon_vceqv8hi_insn = 1541,
  CODE_FOR_neon_vcgtv8hi_insn = 1542,
  CODE_FOR_neon_vcgev8hi_insn = 1543,
  CODE_FOR_neon_vclev8hi_insn = 1544,
  CODE_FOR_neon_vcltv8hi_insn = 1545,
  CODE_FOR_neon_vceqv2si_insn = 1546,
  CODE_FOR_neon_vcgtv2si_insn = 1547,
  CODE_FOR_neon_vcgev2si_insn = 1548,
  CODE_FOR_neon_vclev2si_insn = 1549,
  CODE_FOR_neon_vcltv2si_insn = 1550,
  CODE_FOR_neon_vceqv4si_insn = 1551,
  CODE_FOR_neon_vcgtv4si_insn = 1552,
  CODE_FOR_neon_vcgev4si_insn = 1553,
  CODE_FOR_neon_vclev4si_insn = 1554,
  CODE_FOR_neon_vcltv4si_insn = 1555,
  CODE_FOR_neon_vceqv2sf_insn = 1556,
  CODE_FOR_neon_vcgtv2sf_insn = 1557,
  CODE_FOR_neon_vcgev2sf_insn = 1558,
  CODE_FOR_neon_vclev2sf_insn = 1559,
  CODE_FOR_neon_vcltv2sf_insn = 1560,
  CODE_FOR_neon_vceqv4sf_insn = 1561,
  CODE_FOR_neon_vcgtv4sf_insn = 1562,
  CODE_FOR_neon_vcgev4sf_insn = 1563,
  CODE_FOR_neon_vclev4sf_insn = 1564,
  CODE_FOR_neon_vcltv4sf_insn = 1565,
  CODE_FOR_neon_vceqv2sf_insn_unspec = 1566,
  CODE_FOR_neon_vcgtv2sf_insn_unspec = 1567,
  CODE_FOR_neon_vcgev2sf_insn_unspec = 1568,
  CODE_FOR_neon_vcltv2sf_insn_unspec = 1569,
  CODE_FOR_neon_vclev2sf_insn_unspec = 1570,
  CODE_FOR_neon_vceqv4sf_insn_unspec = 1571,
  CODE_FOR_neon_vcgtv4sf_insn_unspec = 1572,
  CODE_FOR_neon_vcgev4sf_insn_unspec = 1573,
  CODE_FOR_neon_vcltv4sf_insn_unspec = 1574,
  CODE_FOR_neon_vclev4sf_insn_unspec = 1575,
  CODE_FOR_neon_vceqv8hf_fp16insn = 1576,
  CODE_FOR_neon_vcgtv8hf_fp16insn = 1577,
  CODE_FOR_neon_vcgev8hf_fp16insn = 1578,
  CODE_FOR_neon_vclev8hf_fp16insn = 1579,
  CODE_FOR_neon_vcltv8hf_fp16insn = 1580,
  CODE_FOR_neon_vceqv4hf_fp16insn = 1581,
  CODE_FOR_neon_vcgtv4hf_fp16insn = 1582,
  CODE_FOR_neon_vcgev4hf_fp16insn = 1583,
  CODE_FOR_neon_vclev4hf_fp16insn = 1584,
  CODE_FOR_neon_vcltv4hf_fp16insn = 1585,
  CODE_FOR_neon_vceqv8hf_fp16insn_unspec = 1586,
  CODE_FOR_neon_vcgtv8hf_fp16insn_unspec = 1587,
  CODE_FOR_neon_vcgev8hf_fp16insn_unspec = 1588,
  CODE_FOR_neon_vcltv8hf_fp16insn_unspec = 1589,
  CODE_FOR_neon_vclev8hf_fp16insn_unspec = 1590,
  CODE_FOR_neon_vceqv4hf_fp16insn_unspec = 1591,
  CODE_FOR_neon_vcgtv4hf_fp16insn_unspec = 1592,
  CODE_FOR_neon_vcgev4hf_fp16insn_unspec = 1593,
  CODE_FOR_neon_vcltv4hf_fp16insn_unspec = 1594,
  CODE_FOR_neon_vclev4hf_fp16insn_unspec = 1595,
  CODE_FOR_neon_vcgtuv8qi = 1596,
  CODE_FOR_neon_vcgeuv8qi = 1597,
  CODE_FOR_neon_vcgtuv16qi = 1598,
  CODE_FOR_neon_vcgeuv16qi = 1599,
  CODE_FOR_neon_vcgtuv4hi = 1600,
  CODE_FOR_neon_vcgeuv4hi = 1601,
  CODE_FOR_neon_vcgtuv8hi = 1602,
  CODE_FOR_neon_vcgeuv8hi = 1603,
  CODE_FOR_neon_vcgtuv2si = 1604,
  CODE_FOR_neon_vcgeuv2si = 1605,
  CODE_FOR_neon_vcgtuv4si = 1606,
  CODE_FOR_neon_vcgeuv4si = 1607,
  CODE_FOR_neon_vcagtv2sf_insn = 1608,
  CODE_FOR_neon_vcagev2sf_insn = 1609,
  CODE_FOR_neon_vcagtv4sf_insn = 1610,
  CODE_FOR_neon_vcagev4sf_insn = 1611,
  CODE_FOR_neon_vcagev2sf_insn_unspec = 1612,
  CODE_FOR_neon_vcagtv2sf_insn_unspec = 1613,
  CODE_FOR_neon_vcagev4sf_insn_unspec = 1614,
  CODE_FOR_neon_vcagtv4sf_insn_unspec = 1615,
  CODE_FOR_neon_vcagtv8hf_fp16insn = 1616,
  CODE_FOR_neon_vcagev8hf_fp16insn = 1617,
  CODE_FOR_neon_vcaltv8hf_fp16insn = 1618,
  CODE_FOR_neon_vcalev8hf_fp16insn = 1619,
  CODE_FOR_neon_vcagtv4hf_fp16insn = 1620,
  CODE_FOR_neon_vcagev4hf_fp16insn = 1621,
  CODE_FOR_neon_vcaltv4hf_fp16insn = 1622,
  CODE_FOR_neon_vcalev4hf_fp16insn = 1623,
  CODE_FOR_neon_vcagev8hf_fp16insn_unspec = 1624,
  CODE_FOR_neon_vcagtv8hf_fp16insn_unspec = 1625,
  CODE_FOR_neon_vcalev8hf_fp16insn_unspec = 1626,
  CODE_FOR_neon_vcaltv8hf_fp16insn_unspec = 1627,
  CODE_FOR_neon_vcagev4hf_fp16insn_unspec = 1628,
  CODE_FOR_neon_vcagtv4hf_fp16insn_unspec = 1629,
  CODE_FOR_neon_vcalev4hf_fp16insn_unspec = 1630,
  CODE_FOR_neon_vcaltv4hf_fp16insn_unspec = 1631,
  CODE_FOR_neon_vtstv8qi = 1632,
  CODE_FOR_neon_vtstv16qi = 1633,
  CODE_FOR_neon_vtstv4hi = 1634,
  CODE_FOR_neon_vtstv8hi = 1635,
  CODE_FOR_neon_vtstv2si = 1636,
  CODE_FOR_neon_vtstv4si = 1637,
  CODE_FOR_neon_vabdsv8qi = 1638,
  CODE_FOR_neon_vabduv8qi = 1639,
  CODE_FOR_neon_vabdsv16qi = 1640,
  CODE_FOR_neon_vabduv16qi = 1641,
  CODE_FOR_neon_vabdsv4hi = 1642,
  CODE_FOR_neon_vabduv4hi = 1643,
  CODE_FOR_neon_vabdsv8hi = 1644,
  CODE_FOR_neon_vabduv8hi = 1645,
  CODE_FOR_neon_vabdsv2si = 1646,
  CODE_FOR_neon_vabduv2si = 1647,
  CODE_FOR_neon_vabdsv4si = 1648,
  CODE_FOR_neon_vabduv4si = 1649,
  CODE_FOR_neon_vabdv8hf = 1650,
  CODE_FOR_neon_vabdv4hf = 1651,
  CODE_FOR_neon_vabdfv2sf = 1652,
  CODE_FOR_neon_vabdfv4sf = 1653,
  CODE_FOR_neon_vabdlsv8qi = 1654,
  CODE_FOR_neon_vabdluv8qi = 1655,
  CODE_FOR_neon_vabdlsv4hi = 1656,
  CODE_FOR_neon_vabdluv4hi = 1657,
  CODE_FOR_neon_vabdlsv2si = 1658,
  CODE_FOR_neon_vabdluv2si = 1659,
  CODE_FOR_neon_vabasv8qi = 1660,
  CODE_FOR_neon_vabauv8qi = 1661,
  CODE_FOR_neon_vabasv16qi = 1662,
  CODE_FOR_neon_vabauv16qi = 1663,
  CODE_FOR_neon_vabasv4hi = 1664,
  CODE_FOR_neon_vabauv4hi = 1665,
  CODE_FOR_neon_vabasv8hi = 1666,
  CODE_FOR_neon_vabauv8hi = 1667,
  CODE_FOR_neon_vabasv2si = 1668,
  CODE_FOR_neon_vabauv2si = 1669,
  CODE_FOR_neon_vabasv4si = 1670,
  CODE_FOR_neon_vabauv4si = 1671,
  CODE_FOR_neon_vabalsv8qi = 1672,
  CODE_FOR_neon_vabaluv8qi = 1673,
  CODE_FOR_neon_vabalsv4hi = 1674,
  CODE_FOR_neon_vabaluv4hi = 1675,
  CODE_FOR_neon_vabalsv2si = 1676,
  CODE_FOR_neon_vabaluv2si = 1677,
  CODE_FOR_neon_vmaxsv8qi = 1678,
  CODE_FOR_neon_vmaxuv8qi = 1679,
  CODE_FOR_neon_vminsv8qi = 1680,
  CODE_FOR_neon_vminuv8qi = 1681,
  CODE_FOR_neon_vmaxsv16qi = 1682,
  CODE_FOR_neon_vmaxuv16qi = 1683,
  CODE_FOR_neon_vminsv16qi = 1684,
  CODE_FOR_neon_vminuv16qi = 1685,
  CODE_FOR_neon_vmaxsv4hi = 1686,
  CODE_FOR_neon_vmaxuv4hi = 1687,
  CODE_FOR_neon_vminsv4hi = 1688,
  CODE_FOR_neon_vminuv4hi = 1689,
  CODE_FOR_neon_vmaxsv8hi = 1690,
  CODE_FOR_neon_vmaxuv8hi = 1691,
  CODE_FOR_neon_vminsv8hi = 1692,
  CODE_FOR_neon_vminuv8hi = 1693,
  CODE_FOR_neon_vmaxsv2si = 1694,
  CODE_FOR_neon_vmaxuv2si = 1695,
  CODE_FOR_neon_vminsv2si = 1696,
  CODE_FOR_neon_vminuv2si = 1697,
  CODE_FOR_neon_vmaxsv4si = 1698,
  CODE_FOR_neon_vmaxuv4si = 1699,
  CODE_FOR_neon_vminsv4si = 1700,
  CODE_FOR_neon_vminuv4si = 1701,
  CODE_FOR_neon_vmaxfv2sf = 1702,
  CODE_FOR_neon_vminfv2sf = 1703,
  CODE_FOR_neon_vmaxfv4sf = 1704,
  CODE_FOR_neon_vminfv4sf = 1705,
  CODE_FOR_neon_vmaxfv8hf = 1706,
  CODE_FOR_neon_vminfv8hf = 1707,
  CODE_FOR_neon_vmaxfv4hf = 1708,
  CODE_FOR_neon_vminfv4hf = 1709,
  CODE_FOR_neon_vpmaxfv4hf = 1710,
  CODE_FOR_neon_vpminfv4hf = 1711,
  CODE_FOR_neon_vmaxnmv8hf = 1712,
  CODE_FOR_neon_vminnmv8hf = 1713,
  CODE_FOR_neon_vmaxnmv4hf = 1714,
  CODE_FOR_neon_vminnmv4hf = 1715,
  CODE_FOR_neon_vmaxnmv2sf = 1716,
  CODE_FOR_neon_vminnmv2sf = 1717,
  CODE_FOR_neon_vmaxnmv4sf = 1718,
  CODE_FOR_neon_vminnmv4sf = 1719,
  CODE_FOR_fmaxv2sf3 = 1720,
  CODE_FOR_fminv2sf3 = 1721,
  CODE_FOR_fmaxv4sf3 = 1722,
  CODE_FOR_fminv4sf3 = 1723,
  CODE_FOR_neon_vpaddlsv8qi = 1724,
  CODE_FOR_neon_vpaddluv8qi = 1725,
  CODE_FOR_neon_vpaddlsv16qi = 1726,
  CODE_FOR_neon_vpaddluv16qi = 1727,
  CODE_FOR_neon_vpaddlsv4hi = 1728,
  CODE_FOR_neon_vpaddluv4hi = 1729,
  CODE_FOR_neon_vpaddlsv8hi = 1730,
  CODE_FOR_neon_vpaddluv8hi = 1731,
  CODE_FOR_neon_vpaddlsv2si = 1732,
  CODE_FOR_neon_vpaddluv2si = 1733,
  CODE_FOR_neon_vpaddlsv4si = 1734,
  CODE_FOR_neon_vpaddluv4si = 1735,
  CODE_FOR_neon_vpadalsv8qi = 1736,
  CODE_FOR_neon_vpadaluv8qi = 1737,
  CODE_FOR_neon_vpadalsv16qi = 1738,
  CODE_FOR_neon_vpadaluv16qi = 1739,
  CODE_FOR_neon_vpadalsv4hi = 1740,
  CODE_FOR_neon_vpadaluv4hi = 1741,
  CODE_FOR_neon_vpadalsv8hi = 1742,
  CODE_FOR_neon_vpadaluv8hi = 1743,
  CODE_FOR_neon_vpadalsv2si = 1744,
  CODE_FOR_neon_vpadaluv2si = 1745,
  CODE_FOR_neon_vpadalsv4si = 1746,
  CODE_FOR_neon_vpadaluv4si = 1747,
  CODE_FOR_neon_vpmaxsv8qi = 1748,
  CODE_FOR_neon_vpmaxuv8qi = 1749,
  CODE_FOR_neon_vpminsv8qi = 1750,
  CODE_FOR_neon_vpminuv8qi = 1751,
  CODE_FOR_neon_vpmaxsv4hi = 1752,
  CODE_FOR_neon_vpmaxuv4hi = 1753,
  CODE_FOR_neon_vpminsv4hi = 1754,
  CODE_FOR_neon_vpminuv4hi = 1755,
  CODE_FOR_neon_vpmaxsv2si = 1756,
  CODE_FOR_neon_vpmaxuv2si = 1757,
  CODE_FOR_neon_vpminsv2si = 1758,
  CODE_FOR_neon_vpminuv2si = 1759,
  CODE_FOR_neon_vpmaxfv2sf = 1760,
  CODE_FOR_neon_vpminfv2sf = 1761,
  CODE_FOR_neon_vpmaxfv4sf = 1762,
  CODE_FOR_neon_vpminfv4sf = 1763,
  CODE_FOR_neon_vrecpsv2sf = 1764,
  CODE_FOR_neon_vrecpsv4sf = 1765,
  CODE_FOR_neon_vrecpsv8hf = 1766,
  CODE_FOR_neon_vrecpsv4hf = 1767,
  CODE_FOR_neon_vrsqrtsv2sf = 1768,
  CODE_FOR_neon_vrsqrtsv4sf = 1769,
  CODE_FOR_neon_vrsqrtsv8hf = 1770,
  CODE_FOR_neon_vrsqrtsv4hf = 1771,
  CODE_FOR_neon_vqabsv8qi = 1772,
  CODE_FOR_neon_vqabsv16qi = 1773,
  CODE_FOR_neon_vqabsv4hi = 1774,
  CODE_FOR_neon_vqabsv8hi = 1775,
  CODE_FOR_neon_vqabsv2si = 1776,
  CODE_FOR_neon_vqabsv4si = 1777,
  CODE_FOR_neon_bswapv4hi = 1778,
  CODE_FOR_neon_bswapv8hi = 1779,
  CODE_FOR_neon_bswapv2si = 1780,
  CODE_FOR_neon_bswapv4si = 1781,
  CODE_FOR_neon_bswapv2di = 1782,
  CODE_FOR_neon_sdotv8qi = 1783,
  CODE_FOR_neon_udotv8qi = 1784,
  CODE_FOR_neon_sdotv16qi = 1785,
  CODE_FOR_neon_udotv16qi = 1786,
  CODE_FOR_neon_sdot_lanev8qi = 1787,
  CODE_FOR_neon_udot_lanev8qi = 1788,
  CODE_FOR_neon_sdot_lanev16qi = 1789,
  CODE_FOR_neon_udot_lanev16qi = 1790,
  CODE_FOR_neon_vqnegv8qi = 1791,
  CODE_FOR_neon_vqnegv16qi = 1792,
  CODE_FOR_neon_vqnegv4hi = 1793,
  CODE_FOR_neon_vqnegv8hi = 1794,
  CODE_FOR_neon_vqnegv2si = 1795,
  CODE_FOR_neon_vqnegv4si = 1796,
  CODE_FOR_neon_vclsv8qi = 1797,
  CODE_FOR_neon_vclsv16qi = 1798,
  CODE_FOR_neon_vclsv4hi = 1799,
  CODE_FOR_neon_vclsv8hi = 1800,
  CODE_FOR_neon_vclsv2si = 1801,
  CODE_FOR_neon_vclsv4si = 1802,
  CODE_FOR_clzv8qi2 = 1803,
  CODE_FOR_clzv16qi2 = 1804,
  CODE_FOR_clzv4hi2 = 1805,
  CODE_FOR_clzv8hi2 = 1806,
  CODE_FOR_clzv2si2 = 1807,
  CODE_FOR_clzv4si2 = 1808,
  CODE_FOR_popcountv8qi2 = 1809,
  CODE_FOR_popcountv16qi2 = 1810,
  CODE_FOR_neon_vrecpev8hf = 1811,
  CODE_FOR_neon_vrecpev4hf = 1812,
  CODE_FOR_neon_vrecpev2si = 1813,
  CODE_FOR_neon_vrecpev2sf = 1814,
  CODE_FOR_neon_vrecpev4si = 1815,
  CODE_FOR_neon_vrecpev4sf = 1816,
  CODE_FOR_neon_vrsqrtev2si = 1817,
  CODE_FOR_neon_vrsqrtev2sf = 1818,
  CODE_FOR_neon_vrsqrtev4si = 1819,
  CODE_FOR_neon_vrsqrtev4sf = 1820,
  CODE_FOR_neon_vget_lanev8qi_sext_internal = 1821,
  CODE_FOR_neon_vget_lanev4hi_sext_internal = 1822,
  CODE_FOR_neon_vget_lanev2si_sext_internal = 1823,
  CODE_FOR_neon_vget_lanev2sf_sext_internal = 1824,
  CODE_FOR_neon_vget_lanev8qi_zext_internal = 1825,
  CODE_FOR_neon_vget_lanev4hi_zext_internal = 1826,
  CODE_FOR_neon_vget_lanev2si_zext_internal = 1827,
  CODE_FOR_neon_vget_lanev2sf_zext_internal = 1828,
  CODE_FOR_neon_vget_lanev16qi_sext_internal = 1829,
  CODE_FOR_neon_vget_lanev8hi_sext_internal = 1830,
  CODE_FOR_neon_vget_lanev8hf_sext_internal = 1831,
  CODE_FOR_neon_vget_lanev4si_sext_internal = 1832,
  CODE_FOR_neon_vget_lanev4sf_sext_internal = 1833,
  CODE_FOR_neon_vget_lanev16qi_zext_internal = 1834,
  CODE_FOR_neon_vget_lanev8hi_zext_internal = 1835,
  CODE_FOR_neon_vget_lanev8hf_zext_internal = 1836,
  CODE_FOR_neon_vget_lanev4si_zext_internal = 1837,
  CODE_FOR_neon_vget_lanev4sf_zext_internal = 1838,
  CODE_FOR_neon_vdup_nv8qi = 1839,
  CODE_FOR_neon_vdup_nv4hi = 1840,
  CODE_FOR_neon_vdup_nv16qi = 1841,
  CODE_FOR_neon_vdup_nv8hi = 1842,
  CODE_FOR_neon_vdup_nv4hf = 1843,
  CODE_FOR_neon_vdup_nv8hf = 1844,
  CODE_FOR_neon_vdup_nv2si = 1845,
  CODE_FOR_neon_vdup_nv2sf = 1846,
  CODE_FOR_neon_vdup_nv4si = 1847,
  CODE_FOR_neon_vdup_nv4sf = 1848,
  CODE_FOR_neon_vdup_nv2di = 1849,
  CODE_FOR_neon_vdup_lanev8qi_internal = 1850,
  CODE_FOR_neon_vdup_lanev16qi_internal = 1851,
  CODE_FOR_neon_vdup_lanev4hi_internal = 1852,
  CODE_FOR_neon_vdup_lanev8hi_internal = 1853,
  CODE_FOR_neon_vdup_lanev2si_internal = 1854,
  CODE_FOR_neon_vdup_lanev4si_internal = 1855,
  CODE_FOR_neon_vdup_lanev2sf_internal = 1856,
  CODE_FOR_neon_vdup_lanev4sf_internal = 1857,
  CODE_FOR_neon_vdup_lanev8hf_internal = 1858,
  CODE_FOR_neon_vdup_lanev4hf_internal = 1859,
  CODE_FOR_neon_vcombinev8qi = 1872,
  CODE_FOR_neon_vcombinev4hi = 1873,
  CODE_FOR_neon_vcombinev4hf = 1874,
  CODE_FOR_neon_vcombinev2si = 1875,
  CODE_FOR_neon_vcombinev2sf = 1876,
  CODE_FOR_neon_vcombinedi = 1877,
  CODE_FOR_floatv2siv2sf2 = 1878,
  CODE_FOR_floatv4siv4sf2 = 1879,
  CODE_FOR_floatunsv2siv2sf2 = 1880,
  CODE_FOR_floatunsv4siv4sf2 = 1881,
  CODE_FOR_fix_truncv2sfv2si2 = 1882,
  CODE_FOR_fix_truncv4sfv4si2 = 1883,
  CODE_FOR_fixuns_truncv2sfv2si2 = 1884,
  CODE_FOR_fixuns_truncv4sfv4si2 = 1885,
  CODE_FOR_neon_vcvtsv2sf = 1886,
  CODE_FOR_neon_vcvtuv2sf = 1887,
  CODE_FOR_neon_vcvtsv4sf = 1888,
  CODE_FOR_neon_vcvtuv4sf = 1889,
  CODE_FOR_neon_vcvtsv2si = 1890,
  CODE_FOR_neon_vcvtuv2si = 1891,
  CODE_FOR_neon_vcvtsv4si = 1892,
  CODE_FOR_neon_vcvtuv4si = 1893,
  CODE_FOR_neon_vcvtv4sfv4hf = 1894,
  CODE_FOR_neon_vcvtv4hfv4sf = 1895,
  CODE_FOR_neon_vcvtsv4hi = 1896,
  CODE_FOR_neon_vcvtuv4hi = 1897,
  CODE_FOR_neon_vcvtsv8hi = 1898,
  CODE_FOR_neon_vcvtuv8hi = 1899,
  CODE_FOR_neon_vcvtsv8hf = 1900,
  CODE_FOR_neon_vcvtuv8hf = 1901,
  CODE_FOR_neon_vcvtsv4hf = 1902,
  CODE_FOR_neon_vcvtuv4hf = 1903,
  CODE_FOR_neon_vcvts_nv2sf = 1904,
  CODE_FOR_neon_vcvtu_nv2sf = 1905,
  CODE_FOR_neon_vcvts_nv4sf = 1906,
  CODE_FOR_neon_vcvtu_nv4sf = 1907,
  CODE_FOR_neon_vcvts_nv8hf = 1908,
  CODE_FOR_neon_vcvtu_nv8hf = 1909,
  CODE_FOR_neon_vcvts_nv4hf = 1910,
  CODE_FOR_neon_vcvtu_nv4hf = 1911,
  CODE_FOR_neon_vcvts_nv2si = 1912,
  CODE_FOR_neon_vcvtu_nv2si = 1913,
  CODE_FOR_neon_vcvts_nv4si = 1914,
  CODE_FOR_neon_vcvtu_nv4si = 1915,
  CODE_FOR_neon_vcvts_nv4hi = 1916,
  CODE_FOR_neon_vcvtu_nv4hi = 1917,
  CODE_FOR_neon_vcvts_nv8hi = 1918,
  CODE_FOR_neon_vcvtu_nv8hi = 1919,
  CODE_FOR_neon_vcvtasv8hf = 1920,
  CODE_FOR_neon_vcvtauv8hf = 1921,
  CODE_FOR_neon_vcvtmsv8hf = 1922,
  CODE_FOR_neon_vcvtmuv8hf = 1923,
  CODE_FOR_neon_vcvtnsv8hf = 1924,
  CODE_FOR_neon_vcvtnuv8hf = 1925,
  CODE_FOR_neon_vcvtpsv8hf = 1926,
  CODE_FOR_neon_vcvtpuv8hf = 1927,
  CODE_FOR_neon_vcvtasv4hf = 1928,
  CODE_FOR_neon_vcvtauv4hf = 1929,
  CODE_FOR_neon_vcvtmsv4hf = 1930,
  CODE_FOR_neon_vcvtmuv4hf = 1931,
  CODE_FOR_neon_vcvtnsv4hf = 1932,
  CODE_FOR_neon_vcvtnuv4hf = 1933,
  CODE_FOR_neon_vcvtpsv4hf = 1934,
  CODE_FOR_neon_vcvtpuv4hf = 1935,
  CODE_FOR_neon_vmovnv8hi = 1936,
  CODE_FOR_neon_vmovnv4si = 1937,
  CODE_FOR_neon_vmovnv2di = 1938,
  CODE_FOR_neon_vqmovnsv8hi = 1939,
  CODE_FOR_neon_vqmovnuv8hi = 1940,
  CODE_FOR_neon_vqmovnsv4si = 1941,
  CODE_FOR_neon_vqmovnuv4si = 1942,
  CODE_FOR_neon_vqmovnsv2di = 1943,
  CODE_FOR_neon_vqmovnuv2di = 1944,
  CODE_FOR_neon_vqmovunv8hi = 1945,
  CODE_FOR_neon_vqmovunv4si = 1946,
  CODE_FOR_neon_vqmovunv2di = 1947,
  CODE_FOR_neon_vmovlsv8qi = 1948,
  CODE_FOR_neon_vmovluv8qi = 1949,
  CODE_FOR_neon_vmovlsv4hi = 1950,
  CODE_FOR_neon_vmovluv4hi = 1951,
  CODE_FOR_neon_vmovlsv2si = 1952,
  CODE_FOR_neon_vmovluv2si = 1953,
  CODE_FOR_neon_vmul_lanev4hi = 1954,
  CODE_FOR_neon_vmul_lanev2si = 1955,
  CODE_FOR_neon_vmul_lanev2sf = 1956,
  CODE_FOR_neon_vmul_lanev8hi = 1957,
  CODE_FOR_neon_vmul_lanev4si = 1958,
  CODE_FOR_neon_vmul_lanev4sf = 1959,
  CODE_FOR_neon_vmul_lanev8hf = 1960,
  CODE_FOR_neon_vmul_lanev4hf = 1961,
  CODE_FOR_neon_vmulls_lanev4hi = 1962,
  CODE_FOR_neon_vmullu_lanev4hi = 1963,
  CODE_FOR_neon_vmulls_lanev2si = 1964,
  CODE_FOR_neon_vmullu_lanev2si = 1965,
  CODE_FOR_neon_vqdmull_lanev4hi = 1966,
  CODE_FOR_neon_vqdmull_lanev2si = 1967,
  CODE_FOR_neon_vqdmulh_lanev8hi = 1968,
  CODE_FOR_neon_vqrdmulh_lanev8hi = 1969,
  CODE_FOR_neon_vqdmulh_lanev4si = 1970,
  CODE_FOR_neon_vqrdmulh_lanev4si = 1971,
  CODE_FOR_neon_vqdmulh_lanev4hi = 1972,
  CODE_FOR_neon_vqrdmulh_lanev4hi = 1973,
  CODE_FOR_neon_vqdmulh_lanev2si = 1974,
  CODE_FOR_neon_vqrdmulh_lanev2si = 1975,
  CODE_FOR_neon_vqrdmlah_lanev8hi = 1976,
  CODE_FOR_neon_vqrdmlsh_lanev8hi = 1977,
  CODE_FOR_neon_vqrdmlah_lanev4si = 1978,
  CODE_FOR_neon_vqrdmlsh_lanev4si = 1979,
  CODE_FOR_neon_vqrdmlah_lanev4hi = 1980,
  CODE_FOR_neon_vqrdmlsh_lanev4hi = 1981,
  CODE_FOR_neon_vqrdmlah_lanev2si = 1982,
  CODE_FOR_neon_vqrdmlsh_lanev2si = 1983,
  CODE_FOR_neon_vmla_lanev4hi = 1984,
  CODE_FOR_neon_vmla_lanev2si = 1985,
  CODE_FOR_neon_vmla_lanev2sf = 1986,
  CODE_FOR_neon_vmla_lanev8hi = 1987,
  CODE_FOR_neon_vmla_lanev4si = 1988,
  CODE_FOR_neon_vmla_lanev4sf = 1989,
  CODE_FOR_neon_vmlals_lanev4hi = 1990,
  CODE_FOR_neon_vmlalu_lanev4hi = 1991,
  CODE_FOR_neon_vmlals_lanev2si = 1992,
  CODE_FOR_neon_vmlalu_lanev2si = 1993,
  CODE_FOR_neon_vqdmlal_lanev4hi = 1994,
  CODE_FOR_neon_vqdmlal_lanev2si = 1995,
  CODE_FOR_neon_vmls_lanev4hi = 1996,
  CODE_FOR_neon_vmls_lanev2si = 1997,
  CODE_FOR_neon_vmls_lanev2sf = 1998,
  CODE_FOR_neon_vmls_lanev8hi = 1999,
  CODE_FOR_neon_vmls_lanev4si = 2000,
  CODE_FOR_neon_vmls_lanev4sf = 2001,
  CODE_FOR_neon_vmlsls_lanev4hi = 2002,
  CODE_FOR_neon_vmlslu_lanev4hi = 2003,
  CODE_FOR_neon_vmlsls_lanev2si = 2004,
  CODE_FOR_neon_vmlslu_lanev2si = 2005,
  CODE_FOR_neon_vqdmlsl_lanev4hi = 2006,
  CODE_FOR_neon_vqdmlsl_lanev2si = 2007,
  CODE_FOR_neon_vextv8qi = 2008,
  CODE_FOR_neon_vextv16qi = 2009,
  CODE_FOR_neon_vextv4hi = 2010,
  CODE_FOR_neon_vextv8hi = 2011,
  CODE_FOR_neon_vextv2si = 2012,
  CODE_FOR_neon_vextv4si = 2013,
  CODE_FOR_neon_vextv4hf = 2014,
  CODE_FOR_neon_vextv8hf = 2015,
  CODE_FOR_neon_vextv2sf = 2016,
  CODE_FOR_neon_vextv4sf = 2017,
  CODE_FOR_neon_vextdi = 2018,
  CODE_FOR_neon_vextv2di = 2019,
  CODE_FOR_neon_vrev64v8qi = 2020,
  CODE_FOR_neon_vrev64v16qi = 2021,
  CODE_FOR_neon_vrev64v4hi = 2022,
  CODE_FOR_neon_vrev64v8hi = 2023,
  CODE_FOR_neon_vrev64v2si = 2024,
  CODE_FOR_neon_vrev64v4si = 2025,
  CODE_FOR_neon_vrev64v4hf = 2026,
  CODE_FOR_neon_vrev64v8hf = 2027,
  CODE_FOR_neon_vrev64v2sf = 2028,
  CODE_FOR_neon_vrev64v4sf = 2029,
  CODE_FOR_neon_vrev64v2di = 2030,
  CODE_FOR_neon_vrev32v8qi = 2031,
  CODE_FOR_neon_vrev32v4hi = 2032,
  CODE_FOR_neon_vrev32v16qi = 2033,
  CODE_FOR_neon_vrev32v8hi = 2034,
  CODE_FOR_neon_vrev16v8qi = 2035,
  CODE_FOR_neon_vrev16v16qi = 2036,
  CODE_FOR_neon_vbslv8qi_internal = 2037,
  CODE_FOR_neon_vbslv16qi_internal = 2038,
  CODE_FOR_neon_vbslv4hi_internal = 2039,
  CODE_FOR_neon_vbslv8hi_internal = 2040,
  CODE_FOR_neon_vbslv2si_internal = 2041,
  CODE_FOR_neon_vbslv4si_internal = 2042,
  CODE_FOR_neon_vbslv4hf_internal = 2043,
  CODE_FOR_neon_vbslv8hf_internal = 2044,
  CODE_FOR_neon_vbslv2sf_internal = 2045,
  CODE_FOR_neon_vbslv4sf_internal = 2046,
  CODE_FOR_neon_vbsldi_internal = 2047,
  CODE_FOR_neon_vbslv2di_internal = 2048,
  CODE_FOR_neon_vshlsv8qi = 2049,
  CODE_FOR_neon_vshluv8qi = 2050,
  CODE_FOR_neon_vrshlsv8qi = 2051,
  CODE_FOR_neon_vrshluv8qi = 2052,
  CODE_FOR_neon_vshlsv16qi = 2053,
  CODE_FOR_neon_vshluv16qi = 2054,
  CODE_FOR_neon_vrshlsv16qi = 2055,
  CODE_FOR_neon_vrshluv16qi = 2056,
  CODE_FOR_neon_vshlsv4hi = 2057,
  CODE_FOR_neon_vshluv4hi = 2058,
  CODE_FOR_neon_vrshlsv4hi = 2059,
  CODE_FOR_neon_vrshluv4hi = 2060,
  CODE_FOR_neon_vshlsv8hi = 2061,
  CODE_FOR_neon_vshluv8hi = 2062,
  CODE_FOR_neon_vrshlsv8hi = 2063,
  CODE_FOR_neon_vrshluv8hi = 2064,
  CODE_FOR_neon_vshlsv2si = 2065,
  CODE_FOR_neon_vshluv2si = 2066,
  CODE_FOR_neon_vrshlsv2si = 2067,
  CODE_FOR_neon_vrshluv2si = 2068,
  CODE_FOR_neon_vshlsv4si = 2069,
  CODE_FOR_neon_vshluv4si = 2070,
  CODE_FOR_neon_vrshlsv4si = 2071,
  CODE_FOR_neon_vrshluv4si = 2072,
  CODE_FOR_neon_vshlsdi = 2073,
  CODE_FOR_neon_vshludi = 2074,
  CODE_FOR_neon_vrshlsdi = 2075,
  CODE_FOR_neon_vrshludi = 2076,
  CODE_FOR_neon_vshlsv2di = 2077,
  CODE_FOR_neon_vshluv2di = 2078,
  CODE_FOR_neon_vrshlsv2di = 2079,
  CODE_FOR_neon_vrshluv2di = 2080,
  CODE_FOR_neon_vqshlsv8qi = 2081,
  CODE_FOR_neon_vqshluv8qi = 2082,
  CODE_FOR_neon_vqrshlsv8qi = 2083,
  CODE_FOR_neon_vqrshluv8qi = 2084,
  CODE_FOR_neon_vqshlsv16qi = 2085,
  CODE_FOR_neon_vqshluv16qi = 2086,
  CODE_FOR_neon_vqrshlsv16qi = 2087,
  CODE_FOR_neon_vqrshluv16qi = 2088,
  CODE_FOR_neon_vqshlsv4hi = 2089,
  CODE_FOR_neon_vqshluv4hi = 2090,
  CODE_FOR_neon_vqrshlsv4hi = 2091,
  CODE_FOR_neon_vqrshluv4hi = 2092,
  CODE_FOR_neon_vqshlsv8hi = 2093,
  CODE_FOR_neon_vqshluv8hi = 2094,
  CODE_FOR_neon_vqrshlsv8hi = 2095,
  CODE_FOR_neon_vqrshluv8hi = 2096,
  CODE_FOR_neon_vqshlsv2si = 2097,
  CODE_FOR_neon_vqshluv2si = 2098,
  CODE_FOR_neon_vqrshlsv2si = 2099,
  CODE_FOR_neon_vqrshluv2si = 2100,
  CODE_FOR_neon_vqshlsv4si = 2101,
  CODE_FOR_neon_vqshluv4si = 2102,
  CODE_FOR_neon_vqrshlsv4si = 2103,
  CODE_FOR_neon_vqrshluv4si = 2104,
  CODE_FOR_neon_vqshlsdi = 2105,
  CODE_FOR_neon_vqshludi = 2106,
  CODE_FOR_neon_vqrshlsdi = 2107,
  CODE_FOR_neon_vqrshludi = 2108,
  CODE_FOR_neon_vqshlsv2di = 2109,
  CODE_FOR_neon_vqshluv2di = 2110,
  CODE_FOR_neon_vqrshlsv2di = 2111,
  CODE_FOR_neon_vqrshluv2di = 2112,
  CODE_FOR_neon_vshrs_nv8qi = 2113,
  CODE_FOR_neon_vshru_nv8qi = 2114,
  CODE_FOR_neon_vrshrs_nv8qi = 2115,
  CODE_FOR_neon_vrshru_nv8qi = 2116,
  CODE_FOR_neon_vshrs_nv16qi = 2117,
  CODE_FOR_neon_vshru_nv16qi = 2118,
  CODE_FOR_neon_vrshrs_nv16qi = 2119,
  CODE_FOR_neon_vrshru_nv16qi = 2120,
  CODE_FOR_neon_vshrs_nv4hi = 2121,
  CODE_FOR_neon_vshru_nv4hi = 2122,
  CODE_FOR_neon_vrshrs_nv4hi = 2123,
  CODE_FOR_neon_vrshru_nv4hi = 2124,
  CODE_FOR_neon_vshrs_nv8hi = 2125,
  CODE_FOR_neon_vshru_nv8hi = 2126,
  CODE_FOR_neon_vrshrs_nv8hi = 2127,
  CODE_FOR_neon_vrshru_nv8hi = 2128,
  CODE_FOR_neon_vshrs_nv2si = 2129,
  CODE_FOR_neon_vshru_nv2si = 2130,
  CODE_FOR_neon_vrshrs_nv2si = 2131,
  CODE_FOR_neon_vrshru_nv2si = 2132,
  CODE_FOR_neon_vshrs_nv4si = 2133,
  CODE_FOR_neon_vshru_nv4si = 2134,
  CODE_FOR_neon_vrshrs_nv4si = 2135,
  CODE_FOR_neon_vrshru_nv4si = 2136,
  CODE_FOR_neon_vshrs_ndi = 2137,
  CODE_FOR_neon_vshru_ndi = 2138,
  CODE_FOR_neon_vrshrs_ndi = 2139,
  CODE_FOR_neon_vrshru_ndi = 2140,
  CODE_FOR_neon_vshrs_nv2di = 2141,
  CODE_FOR_neon_vshru_nv2di = 2142,
  CODE_FOR_neon_vrshrs_nv2di = 2143,
  CODE_FOR_neon_vrshru_nv2di = 2144,
  CODE_FOR_neon_vshrn_nv8hi = 2145,
  CODE_FOR_neon_vrshrn_nv8hi = 2146,
  CODE_FOR_neon_vshrn_nv4si = 2147,
  CODE_FOR_neon_vrshrn_nv4si = 2148,
  CODE_FOR_neon_vshrn_nv2di = 2149,
  CODE_FOR_neon_vrshrn_nv2di = 2150,
  CODE_FOR_neon_vqshrns_nv8hi = 2151,
  CODE_FOR_neon_vqshrnu_nv8hi = 2152,
  CODE_FOR_neon_vqrshrns_nv8hi = 2153,
  CODE_FOR_neon_vqrshrnu_nv8hi = 2154,
  CODE_FOR_neon_vqshrns_nv4si = 2155,
  CODE_FOR_neon_vqshrnu_nv4si = 2156,
  CODE_FOR_neon_vqrshrns_nv4si = 2157,
  CODE_FOR_neon_vqrshrnu_nv4si = 2158,
  CODE_FOR_neon_vqshrns_nv2di = 2159,
  CODE_FOR_neon_vqshrnu_nv2di = 2160,
  CODE_FOR_neon_vqrshrns_nv2di = 2161,
  CODE_FOR_neon_vqrshrnu_nv2di = 2162,
  CODE_FOR_neon_vqshrun_nv8hi = 2163,
  CODE_FOR_neon_vqrshrun_nv8hi = 2164,
  CODE_FOR_neon_vqshrun_nv4si = 2165,
  CODE_FOR_neon_vqrshrun_nv4si = 2166,
  CODE_FOR_neon_vqshrun_nv2di = 2167,
  CODE_FOR_neon_vqrshrun_nv2di = 2168,
  CODE_FOR_neon_vshl_nv8qi = 2169,
  CODE_FOR_neon_vshl_nv16qi = 2170,
  CODE_FOR_neon_vshl_nv4hi = 2171,
  CODE_FOR_neon_vshl_nv8hi = 2172,
  CODE_FOR_neon_vshl_nv2si = 2173,
  CODE_FOR_neon_vshl_nv4si = 2174,
  CODE_FOR_neon_vshl_ndi = 2175,
  CODE_FOR_neon_vshl_nv2di = 2176,
  CODE_FOR_neon_vqshl_s_nv8qi = 2177,
  CODE_FOR_neon_vqshl_u_nv8qi = 2178,
  CODE_FOR_neon_vqshl_s_nv16qi = 2179,
  CODE_FOR_neon_vqshl_u_nv16qi = 2180,
  CODE_FOR_neon_vqshl_s_nv4hi = 2181,
  CODE_FOR_neon_vqshl_u_nv4hi = 2182,
  CODE_FOR_neon_vqshl_s_nv8hi = 2183,
  CODE_FOR_neon_vqshl_u_nv8hi = 2184,
  CODE_FOR_neon_vqshl_s_nv2si = 2185,
  CODE_FOR_neon_vqshl_u_nv2si = 2186,
  CODE_FOR_neon_vqshl_s_nv4si = 2187,
  CODE_FOR_neon_vqshl_u_nv4si = 2188,
  CODE_FOR_neon_vqshl_s_ndi = 2189,
  CODE_FOR_neon_vqshl_u_ndi = 2190,
  CODE_FOR_neon_vqshl_s_nv2di = 2191,
  CODE_FOR_neon_vqshl_u_nv2di = 2192,
  CODE_FOR_neon_vqshlu_nv8qi = 2193,
  CODE_FOR_neon_vqshlu_nv16qi = 2194,
  CODE_FOR_neon_vqshlu_nv4hi = 2195,
  CODE_FOR_neon_vqshlu_nv8hi = 2196,
  CODE_FOR_neon_vqshlu_nv2si = 2197,
  CODE_FOR_neon_vqshlu_nv4si = 2198,
  CODE_FOR_neon_vqshlu_ndi = 2199,
  CODE_FOR_neon_vqshlu_nv2di = 2200,
  CODE_FOR_neon_vshlls_nv8qi = 2201,
  CODE_FOR_neon_vshllu_nv8qi = 2202,
  CODE_FOR_neon_vshlls_nv4hi = 2203,
  CODE_FOR_neon_vshllu_nv4hi = 2204,
  CODE_FOR_neon_vshlls_nv2si = 2205,
  CODE_FOR_neon_vshllu_nv2si = 2206,
  CODE_FOR_neon_vsras_nv8qi = 2207,
  CODE_FOR_neon_vsrau_nv8qi = 2208,
  CODE_FOR_neon_vrsras_nv8qi = 2209,
  CODE_FOR_neon_vrsrau_nv8qi = 2210,
  CODE_FOR_neon_vsras_nv16qi = 2211,
  CODE_FOR_neon_vsrau_nv16qi = 2212,
  CODE_FOR_neon_vrsras_nv16qi = 2213,
  CODE_FOR_neon_vrsrau_nv16qi = 2214,
  CODE_FOR_neon_vsras_nv4hi = 2215,
  CODE_FOR_neon_vsrau_nv4hi = 2216,
  CODE_FOR_neon_vrsras_nv4hi = 2217,
  CODE_FOR_neon_vrsrau_nv4hi = 2218,
  CODE_FOR_neon_vsras_nv8hi = 2219,
  CODE_FOR_neon_vsrau_nv8hi = 2220,
  CODE_FOR_neon_vrsras_nv8hi = 2221,
  CODE_FOR_neon_vrsrau_nv8hi = 2222,
  CODE_FOR_neon_vsras_nv2si = 2223,
  CODE_FOR_neon_vsrau_nv2si = 2224,
  CODE_FOR_neon_vrsras_nv2si = 2225,
  CODE_FOR_neon_vrsrau_nv2si = 2226,
  CODE_FOR_neon_vsras_nv4si = 2227,
  CODE_FOR_neon_vsrau_nv4si = 2228,
  CODE_FOR_neon_vrsras_nv4si = 2229,
  CODE_FOR_neon_vrsrau_nv4si = 2230,
  CODE_FOR_neon_vsras_ndi = 2231,
  CODE_FOR_neon_vsrau_ndi = 2232,
  CODE_FOR_neon_vrsras_ndi = 2233,
  CODE_FOR_neon_vrsrau_ndi = 2234,
  CODE_FOR_neon_vsras_nv2di = 2235,
  CODE_FOR_neon_vsrau_nv2di = 2236,
  CODE_FOR_neon_vrsras_nv2di = 2237,
  CODE_FOR_neon_vrsrau_nv2di = 2238,
  CODE_FOR_neon_vsri_nv8qi = 2239,
  CODE_FOR_neon_vsri_nv16qi = 2240,
  CODE_FOR_neon_vsri_nv4hi = 2241,
  CODE_FOR_neon_vsri_nv8hi = 2242,
  CODE_FOR_neon_vsri_nv2si = 2243,
  CODE_FOR_neon_vsri_nv4si = 2244,
  CODE_FOR_neon_vsri_ndi = 2245,
  CODE_FOR_neon_vsri_nv2di = 2246,
  CODE_FOR_neon_vsli_nv8qi = 2247,
  CODE_FOR_neon_vsli_nv16qi = 2248,
  CODE_FOR_neon_vsli_nv4hi = 2249,
  CODE_FOR_neon_vsli_nv8hi = 2250,
  CODE_FOR_neon_vsli_nv2si = 2251,
  CODE_FOR_neon_vsli_nv4si = 2252,
  CODE_FOR_neon_vsli_ndi = 2253,
  CODE_FOR_neon_vsli_nv2di = 2254,
  CODE_FOR_neon_vtbl1v8qi = 2255,
  CODE_FOR_neon_vtbl2v8qi = 2256,
  CODE_FOR_neon_vtbl3v8qi = 2257,
  CODE_FOR_neon_vtbl4v8qi = 2258,
  CODE_FOR_neon_vtbl1v16qi = 2259,
  CODE_FOR_neon_vtbl2v16qi = 2260,
  CODE_FOR_neon_vcombinev16qi = 2261,
  CODE_FOR_neon_vtbx1v8qi = 2262,
  CODE_FOR_neon_vtbx2v8qi = 2263,
  CODE_FOR_neon_vtbx3v8qi = 2264,
  CODE_FOR_neon_vtbx4v8qi = 2265,
  CODE_FOR_neon_vld1v8qi = 2296,
  CODE_FOR_neon_vld1v16qi = 2297,
  CODE_FOR_neon_vld1v4hi = 2298,
  CODE_FOR_neon_vld1v8hi = 2299,
  CODE_FOR_neon_vld1v2si = 2300,
  CODE_FOR_neon_vld1v4si = 2301,
  CODE_FOR_neon_vld1v4hf = 2302,
  CODE_FOR_neon_vld1v8hf = 2303,
  CODE_FOR_neon_vld1v2sf = 2304,
  CODE_FOR_neon_vld1v4sf = 2305,
  CODE_FOR_neon_vld1di = 2306,
  CODE_FOR_neon_vld1v2di = 2307,
  CODE_FOR_neon_vld1_lanev8qi = 2308,
  CODE_FOR_neon_vld1_lanev4hi = 2309,
  CODE_FOR_neon_vld1_lanev4hf = 2310,
  CODE_FOR_neon_vld1_lanev2si = 2311,
  CODE_FOR_neon_vld1_lanev2sf = 2312,
  CODE_FOR_neon_vld1_lanedi = 2313,
  CODE_FOR_neon_vld1_lanev16qi = 2314,
  CODE_FOR_neon_vld1_lanev8hi = 2315,
  CODE_FOR_neon_vld1_lanev8hf = 2316,
  CODE_FOR_neon_vld1_lanev4si = 2317,
  CODE_FOR_neon_vld1_lanev4sf = 2318,
  CODE_FOR_neon_vld1_lanev2di = 2319,
  CODE_FOR_neon_vld1_dupv8qi = 2320,
  CODE_FOR_neon_vld1_dupv4hi = 2321,
  CODE_FOR_neon_vld1_dupv4hf = 2322,
  CODE_FOR_neon_vld1_dupv2si = 2323,
  CODE_FOR_neon_vld1_dupv2sf = 2324,
  CODE_FOR_neon_vld1_dupv16qi = 2325,
  CODE_FOR_neon_vld1_dupv8hi = 2326,
  CODE_FOR_neon_vld1_dupv8hf = 2327,
  CODE_FOR_neon_vld1_dupv4si = 2328,
  CODE_FOR_neon_vld1_dupv4sf = 2329,
  CODE_FOR_neon_vld1_dupv2di = 2330,
  CODE_FOR_neon_vst1v8qi = 2331,
  CODE_FOR_neon_vst1v16qi = 2332,
  CODE_FOR_neon_vst1v4hi = 2333,
  CODE_FOR_neon_vst1v8hi = 2334,
  CODE_FOR_neon_vst1v2si = 2335,
  CODE_FOR_neon_vst1v4si = 2336,
  CODE_FOR_neon_vst1v4hf = 2337,
  CODE_FOR_neon_vst1v8hf = 2338,
  CODE_FOR_neon_vst1v2sf = 2339,
  CODE_FOR_neon_vst1v4sf = 2340,
  CODE_FOR_neon_vst1di = 2341,
  CODE_FOR_neon_vst1v2di = 2342,
  CODE_FOR_neon_vst1_lanev8qi = 2343,
  CODE_FOR_neon_vst1_lanev4hi = 2344,
  CODE_FOR_neon_vst1_lanev4hf = 2345,
  CODE_FOR_neon_vst1_lanev2si = 2346,
  CODE_FOR_neon_vst1_lanev2sf = 2347,
  CODE_FOR_neon_vst1_lanedi = 2348,
  CODE_FOR_neon_vst1_lanev16qi = 2349,
  CODE_FOR_neon_vst1_lanev8hi = 2350,
  CODE_FOR_neon_vst1_lanev8hf = 2351,
  CODE_FOR_neon_vst1_lanev4si = 2352,
  CODE_FOR_neon_vst1_lanev4sf = 2353,
  CODE_FOR_neon_vst1_lanev2di = 2354,
  CODE_FOR_neon_vld2v8qi = 2355,
  CODE_FOR_neon_vld2v4hi = 2356,
  CODE_FOR_neon_vld2v4hf = 2357,
  CODE_FOR_neon_vld2v2si = 2358,
  CODE_FOR_neon_vld2v2sf = 2359,
  CODE_FOR_neon_vld2di = 2360,
  CODE_FOR_neon_vld2v16qi = 2361,
  CODE_FOR_neon_vld2v8hi = 2362,
  CODE_FOR_neon_vld2v8hf = 2363,
  CODE_FOR_neon_vld2v4si = 2364,
  CODE_FOR_neon_vld2v4sf = 2365,
  CODE_FOR_neon_vld2_lanev8qi = 2366,
  CODE_FOR_neon_vld2_lanev4hi = 2367,
  CODE_FOR_neon_vld2_lanev4hf = 2368,
  CODE_FOR_neon_vld2_lanev2si = 2369,
  CODE_FOR_neon_vld2_lanev2sf = 2370,
  CODE_FOR_neon_vld2_lanev8hi = 2371,
  CODE_FOR_neon_vld2_lanev8hf = 2372,
  CODE_FOR_neon_vld2_lanev4si = 2373,
  CODE_FOR_neon_vld2_lanev4sf = 2374,
  CODE_FOR_neon_vld2_dupv8qi = 2375,
  CODE_FOR_neon_vld2_dupv4hi = 2376,
  CODE_FOR_neon_vld2_dupv4hf = 2377,
  CODE_FOR_neon_vld2_dupv2si = 2378,
  CODE_FOR_neon_vld2_dupv2sf = 2379,
  CODE_FOR_neon_vld2_dupdi = 2380,
  CODE_FOR_neon_vst2v8qi = 2381,
  CODE_FOR_neon_vst2v4hi = 2382,
  CODE_FOR_neon_vst2v4hf = 2383,
  CODE_FOR_neon_vst2v2si = 2384,
  CODE_FOR_neon_vst2v2sf = 2385,
  CODE_FOR_neon_vst2di = 2386,
  CODE_FOR_neon_vst2v16qi = 2387,
  CODE_FOR_neon_vst2v8hi = 2388,
  CODE_FOR_neon_vst2v8hf = 2389,
  CODE_FOR_neon_vst2v4si = 2390,
  CODE_FOR_neon_vst2v4sf = 2391,
  CODE_FOR_neon_vst2_lanev8qi = 2392,
  CODE_FOR_neon_vst2_lanev4hi = 2393,
  CODE_FOR_neon_vst2_lanev4hf = 2394,
  CODE_FOR_neon_vst2_lanev2si = 2395,
  CODE_FOR_neon_vst2_lanev2sf = 2396,
  CODE_FOR_neon_vst2_lanev8hi = 2397,
  CODE_FOR_neon_vst2_lanev8hf = 2398,
  CODE_FOR_neon_vst2_lanev4si = 2399,
  CODE_FOR_neon_vst2_lanev4sf = 2400,
  CODE_FOR_neon_vld3v8qi = 2401,
  CODE_FOR_neon_vld3v4hi = 2402,
  CODE_FOR_neon_vld3v4hf = 2403,
  CODE_FOR_neon_vld3v2si = 2404,
  CODE_FOR_neon_vld3v2sf = 2405,
  CODE_FOR_neon_vld3di = 2406,
  CODE_FOR_neon_vld3qav16qi = 2407,
  CODE_FOR_neon_vld3qav8hi = 2408,
  CODE_FOR_neon_vld3qav8hf = 2409,
  CODE_FOR_neon_vld3qav4si = 2410,
  CODE_FOR_neon_vld3qav4sf = 2411,
  CODE_FOR_neon_vld3qbv16qi = 2412,
  CODE_FOR_neon_vld3qbv8hi = 2413,
  CODE_FOR_neon_vld3qbv8hf = 2414,
  CODE_FOR_neon_vld3qbv4si = 2415,
  CODE_FOR_neon_vld3qbv4sf = 2416,
  CODE_FOR_neon_vld3_lanev8qi = 2417,
  CODE_FOR_neon_vld3_lanev4hi = 2418,
  CODE_FOR_neon_vld3_lanev4hf = 2419,
  CODE_FOR_neon_vld3_lanev2si = 2420,
  CODE_FOR_neon_vld3_lanev2sf = 2421,
  CODE_FOR_neon_vld3_lanev8hi = 2422,
  CODE_FOR_neon_vld3_lanev8hf = 2423,
  CODE_FOR_neon_vld3_lanev4si = 2424,
  CODE_FOR_neon_vld3_lanev4sf = 2425,
  CODE_FOR_neon_vld3_dupv8qi = 2426,
  CODE_FOR_neon_vld3_dupv4hi = 2427,
  CODE_FOR_neon_vld3_dupv4hf = 2428,
  CODE_FOR_neon_vld3_dupv2si = 2429,
  CODE_FOR_neon_vld3_dupv2sf = 2430,
  CODE_FOR_neon_vld3_dupdi = 2431,
  CODE_FOR_neon_vst3v8qi = 2432,
  CODE_FOR_neon_vst3v4hi = 2433,
  CODE_FOR_neon_vst3v4hf = 2434,
  CODE_FOR_neon_vst3v2si = 2435,
  CODE_FOR_neon_vst3v2sf = 2436,
  CODE_FOR_neon_vst3di = 2437,
  CODE_FOR_neon_vst3qav16qi = 2438,
  CODE_FOR_neon_vst3qav8hi = 2439,
  CODE_FOR_neon_vst3qav8hf = 2440,
  CODE_FOR_neon_vst3qav4si = 2441,
  CODE_FOR_neon_vst3qav4sf = 2442,
  CODE_FOR_neon_vst3qbv16qi = 2443,
  CODE_FOR_neon_vst3qbv8hi = 2444,
  CODE_FOR_neon_vst3qbv8hf = 2445,
  CODE_FOR_neon_vst3qbv4si = 2446,
  CODE_FOR_neon_vst3qbv4sf = 2447,
  CODE_FOR_neon_vst3_lanev8qi = 2448,
  CODE_FOR_neon_vst3_lanev4hi = 2449,
  CODE_FOR_neon_vst3_lanev4hf = 2450,
  CODE_FOR_neon_vst3_lanev2si = 2451,
  CODE_FOR_neon_vst3_lanev2sf = 2452,
  CODE_FOR_neon_vst3_lanev8hi = 2453,
  CODE_FOR_neon_vst3_lanev8hf = 2454,
  CODE_FOR_neon_vst3_lanev4si = 2455,
  CODE_FOR_neon_vst3_lanev4sf = 2456,
  CODE_FOR_neon_vld4v8qi = 2457,
  CODE_FOR_neon_vld4v4hi = 2458,
  CODE_FOR_neon_vld4v4hf = 2459,
  CODE_FOR_neon_vld4v2si = 2460,
  CODE_FOR_neon_vld4v2sf = 2461,
  CODE_FOR_neon_vld4di = 2462,
  CODE_FOR_neon_vld4qav16qi = 2463,
  CODE_FOR_neon_vld4qav8hi = 2464,
  CODE_FOR_neon_vld4qav8hf = 2465,
  CODE_FOR_neon_vld4qav4si = 2466,
  CODE_FOR_neon_vld4qav4sf = 2467,
  CODE_FOR_neon_vld4qbv16qi = 2468,
  CODE_FOR_neon_vld4qbv8hi = 2469,
  CODE_FOR_neon_vld4qbv8hf = 2470,
  CODE_FOR_neon_vld4qbv4si = 2471,
  CODE_FOR_neon_vld4qbv4sf = 2472,
  CODE_FOR_neon_vld4_lanev8qi = 2473,
  CODE_FOR_neon_vld4_lanev4hi = 2474,
  CODE_FOR_neon_vld4_lanev4hf = 2475,
  CODE_FOR_neon_vld4_lanev2si = 2476,
  CODE_FOR_neon_vld4_lanev2sf = 2477,
  CODE_FOR_neon_vld4_lanev8hi = 2478,
  CODE_FOR_neon_vld4_lanev8hf = 2479,
  CODE_FOR_neon_vld4_lanev4si = 2480,
  CODE_FOR_neon_vld4_lanev4sf = 2481,
  CODE_FOR_neon_vld4_dupv8qi = 2482,
  CODE_FOR_neon_vld4_dupv4hi = 2483,
  CODE_FOR_neon_vld4_dupv4hf = 2484,
  CODE_FOR_neon_vld4_dupv2si = 2485,
  CODE_FOR_neon_vld4_dupv2sf = 2486,
  CODE_FOR_neon_vld4_dupdi = 2487,
  CODE_FOR_neon_vst4v8qi = 2488,
  CODE_FOR_neon_vst4v4hi = 2489,
  CODE_FOR_neon_vst4v4hf = 2490,
  CODE_FOR_neon_vst4v2si = 2491,
  CODE_FOR_neon_vst4v2sf = 2492,
  CODE_FOR_neon_vst4di = 2493,
  CODE_FOR_neon_vst4qav16qi = 2494,
  CODE_FOR_neon_vst4qav8hi = 2495,
  CODE_FOR_neon_vst4qav8hf = 2496,
  CODE_FOR_neon_vst4qav4si = 2497,
  CODE_FOR_neon_vst4qav4sf = 2498,
  CODE_FOR_neon_vst4qbv16qi = 2499,
  CODE_FOR_neon_vst4qbv8hi = 2500,
  CODE_FOR_neon_vst4qbv8hf = 2501,
  CODE_FOR_neon_vst4qbv4si = 2502,
  CODE_FOR_neon_vst4qbv4sf = 2503,
  CODE_FOR_neon_vst4_lanev8qi = 2504,
  CODE_FOR_neon_vst4_lanev4hi = 2505,
  CODE_FOR_neon_vst4_lanev4hf = 2506,
  CODE_FOR_neon_vst4_lanev2si = 2507,
  CODE_FOR_neon_vst4_lanev2sf = 2508,
  CODE_FOR_neon_vst4_lanev8hi = 2509,
  CODE_FOR_neon_vst4_lanev8hf = 2510,
  CODE_FOR_neon_vst4_lanev4si = 2511,
  CODE_FOR_neon_vst4_lanev4sf = 2512,
  CODE_FOR_neon_vec_unpacks_lo_v16qi = 2513,
  CODE_FOR_neon_vec_unpacku_lo_v16qi = 2514,
  CODE_FOR_neon_vec_unpacks_lo_v8hi = 2515,
  CODE_FOR_neon_vec_unpacku_lo_v8hi = 2516,
  CODE_FOR_neon_vec_unpacks_lo_v4si = 2517,
  CODE_FOR_neon_vec_unpacku_lo_v4si = 2518,
  CODE_FOR_neon_vec_unpacks_hi_v16qi = 2519,
  CODE_FOR_neon_vec_unpacku_hi_v16qi = 2520,
  CODE_FOR_neon_vec_unpacks_hi_v8hi = 2521,
  CODE_FOR_neon_vec_unpacku_hi_v8hi = 2522,
  CODE_FOR_neon_vec_unpacks_hi_v4si = 2523,
  CODE_FOR_neon_vec_unpacku_hi_v4si = 2524,
  CODE_FOR_neon_vec_smult_lo_v16qi = 2525,
  CODE_FOR_neon_vec_umult_lo_v16qi = 2526,
  CODE_FOR_neon_vec_smult_lo_v8hi = 2527,
  CODE_FOR_neon_vec_umult_lo_v8hi = 2528,
  CODE_FOR_neon_vec_smult_lo_v4si = 2529,
  CODE_FOR_neon_vec_umult_lo_v4si = 2530,
  CODE_FOR_neon_vec_smult_hi_v16qi = 2531,
  CODE_FOR_neon_vec_umult_hi_v16qi = 2532,
  CODE_FOR_neon_vec_smult_hi_v8hi = 2533,
  CODE_FOR_neon_vec_umult_hi_v8hi = 2534,
  CODE_FOR_neon_vec_smult_hi_v4si = 2535,
  CODE_FOR_neon_vec_umult_hi_v4si = 2536,
  CODE_FOR_neon_vec_sshiftl_v8qi = 2537,
  CODE_FOR_neon_vec_ushiftl_v8qi = 2538,
  CODE_FOR_neon_vec_sshiftl_v4hi = 2539,
  CODE_FOR_neon_vec_ushiftl_v4hi = 2540,
  CODE_FOR_neon_vec_sshiftl_v2si = 2541,
  CODE_FOR_neon_vec_ushiftl_v2si = 2542,
  CODE_FOR_neon_unpacks_v8qi = 2543,
  CODE_FOR_neon_unpacku_v8qi = 2544,
  CODE_FOR_neon_unpacks_v4hi = 2545,
  CODE_FOR_neon_unpacku_v4hi = 2546,
  CODE_FOR_neon_unpacks_v2si = 2547,
  CODE_FOR_neon_unpacku_v2si = 2548,
  CODE_FOR_neon_vec_smult_v8qi = 2549,
  CODE_FOR_neon_vec_umult_v8qi = 2550,
  CODE_FOR_neon_vec_smult_v4hi = 2551,
  CODE_FOR_neon_vec_umult_v4hi = 2552,
  CODE_FOR_neon_vec_smult_v2si = 2553,
  CODE_FOR_neon_vec_umult_v2si = 2554,
  CODE_FOR_vec_pack_trunc_v8hi = 2555,
  CODE_FOR_vec_pack_trunc_v4si = 2556,
  CODE_FOR_vec_pack_trunc_v2di = 2557,
  CODE_FOR_neon_vec_pack_trunc_v8hi = 2558,
  CODE_FOR_neon_vec_pack_trunc_v4si = 2559,
  CODE_FOR_neon_vec_pack_trunc_v2di = 2560,
  CODE_FOR_neon_vabdv4hf_2 = 2561,
  CODE_FOR_neon_vabdv8hf_2 = 2562,
  CODE_FOR_neon_vabdv2sf_2 = 2563,
  CODE_FOR_neon_vabdv4sf_2 = 2564,
  CODE_FOR_neon_vabdv4hf_3 = 2565,
  CODE_FOR_neon_vabdv8hf_3 = 2566,
  CODE_FOR_neon_vabdv2sf_3 = 2567,
  CODE_FOR_neon_vabdv4sf_3 = 2568,
  CODE_FOR_crypto_aesmc = 2569,
  CODE_FOR_crypto_aesimc = 2570,
  CODE_FOR_crypto_aesd = 2571,
  CODE_FOR_crypto_aese = 2572,
  CODE_FOR_crypto_sha1su1 = 2573,
  CODE_FOR_crypto_sha256su0 = 2574,
  CODE_FOR_crypto_sha1su0 = 2575,
  CODE_FOR_crypto_sha256h = 2576,
  CODE_FOR_crypto_sha256h2 = 2577,
  CODE_FOR_crypto_sha256su1 = 2578,
  CODE_FOR_crypto_sha1h = 2579,
  CODE_FOR_crypto_vmullp64 = 2580,
  CODE_FOR_crypto_sha1c = 2581,
  CODE_FOR_crypto_sha1m = 2582,
  CODE_FOR_crypto_sha1p = 2583,
  CODE_FOR_atomic_loadqi = 2585,
  CODE_FOR_atomic_loadhi = 2586,
  CODE_FOR_atomic_loadsi = 2587,
  CODE_FOR_atomic_storeqi = 2588,
  CODE_FOR_atomic_storehi = 2589,
  CODE_FOR_atomic_storesi = 2590,
   CODE_FOR_arm_atomic_loaddi2_ldrd = CODE_FOR_nothing,
  CODE_FOR_atomic_compare_and_swap32qi_1 = 2591,
  CODE_FOR_atomic_compare_and_swap32hi_1 = 2592,
  CODE_FOR_atomic_compare_and_swapt1qi_1 = 2593,
  CODE_FOR_atomic_compare_and_swapt1hi_1 = 2594,
  CODE_FOR_atomic_compare_and_swap32si_1 = 2595,
   CODE_FOR_atomic_compare_and_swap32di_1 = CODE_FOR_nothing,
  CODE_FOR_atomic_compare_and_swapt1si_1 = 2596,
  CODE_FOR_atomic_compare_and_swapt1di_1 = 2597,
  CODE_FOR_atomic_exchangeqi = 2598,
  CODE_FOR_atomic_exchangehi = 2599,
  CODE_FOR_atomic_exchangesi = 2600,
   CODE_FOR_atomic_exchangedi = CODE_FOR_nothing,
  CODE_FOR_atomic_addqi = 2601,
  CODE_FOR_atomic_subqi = 2602,
  CODE_FOR_atomic_orqi = 2603,
  CODE_FOR_atomic_xorqi = 2604,
  CODE_FOR_atomic_andqi = 2605,
  CODE_FOR_atomic_addhi = 2606,
  CODE_FOR_atomic_subhi = 2607,
  CODE_FOR_atomic_orhi = 2608,
  CODE_FOR_atomic_xorhi = 2609,
  CODE_FOR_atomic_andhi = 2610,
  CODE_FOR_atomic_addsi = 2611,
  CODE_FOR_atomic_subsi = 2612,
  CODE_FOR_atomic_orsi = 2613,
  CODE_FOR_atomic_xorsi = 2614,
  CODE_FOR_atomic_andsi = 2615,
   CODE_FOR_atomic_adddi = CODE_FOR_nothing,
   CODE_FOR_atomic_subdi = CODE_FOR_nothing,
   CODE_FOR_atomic_ordi = CODE_FOR_nothing,
   CODE_FOR_atomic_xordi = CODE_FOR_nothing,
   CODE_FOR_atomic_anddi = CODE_FOR_nothing,
  CODE_FOR_atomic_nandqi = 2616,
  CODE_FOR_atomic_nandhi = 2617,
  CODE_FOR_atomic_nandsi = 2618,
   CODE_FOR_atomic_nanddi = CODE_FOR_nothing,
  CODE_FOR_atomic_fetch_addqi = 2619,
  CODE_FOR_atomic_fetch_subqi = 2620,
  CODE_FOR_atomic_fetch_orqi = 2621,
  CODE_FOR_atomic_fetch_xorqi = 2622,
  CODE_FOR_atomic_fetch_andqi = 2623,
  CODE_FOR_atomic_fetch_addhi = 2624,
  CODE_FOR_atomic_fetch_subhi = 2625,
  CODE_FOR_atomic_fetch_orhi = 2626,
  CODE_FOR_atomic_fetch_xorhi = 2627,
  CODE_FOR_atomic_fetch_andhi = 2628,
  CODE_FOR_atomic_fetch_addsi = 2629,
  CODE_FOR_atomic_fetch_subsi = 2630,
  CODE_FOR_atomic_fetch_orsi = 2631,
  CODE_FOR_atomic_fetch_xorsi = 2632,
  CODE_FOR_atomic_fetch_andsi = 2633,
   CODE_FOR_atomic_fetch_adddi = CODE_FOR_nothing,
   CODE_FOR_atomic_fetch_subdi = CODE_FOR_nothing,
   CODE_FOR_atomic_fetch_ordi = CODE_FOR_nothing,
   CODE_FOR_atomic_fetch_xordi = CODE_FOR_nothing,
   CODE_FOR_atomic_fetch_anddi = CODE_FOR_nothing,
  CODE_FOR_atomic_fetch_nandqi = 2634,
  CODE_FOR_atomic_fetch_nandhi = 2635,
  CODE_FOR_atomic_fetch_nandsi = 2636,
   CODE_FOR_atomic_fetch_nanddi = CODE_FOR_nothing,
  CODE_FOR_atomic_add_fetchqi = 2637,
  CODE_FOR_atomic_sub_fetchqi = 2638,
  CODE_FOR_atomic_or_fetchqi = 2639,
  CODE_FOR_atomic_xor_fetchqi = 2640,
  CODE_FOR_atomic_and_fetchqi = 2641,
  CODE_FOR_atomic_add_fetchhi = 2642,
  CODE_FOR_atomic_sub_fetchhi = 2643,
  CODE_FOR_atomic_or_fetchhi = 2644,
  CODE_FOR_atomic_xor_fetchhi = 2645,
  CODE_FOR_atomic_and_fetchhi = 2646,
  CODE_FOR_atomic_add_fetchsi = 2647,
  CODE_FOR_atomic_sub_fetchsi = 2648,
  CODE_FOR_atomic_or_fetchsi = 2649,
  CODE_FOR_atomic_xor_fetchsi = 2650,
  CODE_FOR_atomic_and_fetchsi = 2651,
   CODE_FOR_atomic_add_fetchdi = CODE_FOR_nothing,
   CODE_FOR_atomic_sub_fetchdi = CODE_FOR_nothing,
   CODE_FOR_atomic_or_fetchdi = CODE_FOR_nothing,
   CODE_FOR_atomic_xor_fetchdi = CODE_FOR_nothing,
   CODE_FOR_atomic_and_fetchdi = CODE_FOR_nothing,
  CODE_FOR_atomic_nand_fetchqi = 2652,
  CODE_FOR_atomic_nand_fetchhi = 2653,
  CODE_FOR_atomic_nand_fetchsi = 2654,
   CODE_FOR_atomic_nand_fetchdi = CODE_FOR_nothing,
  CODE_FOR_arm_load_exclusiveqi = 2655,
  CODE_FOR_arm_load_exclusivehi = 2656,
  CODE_FOR_arm_load_acquire_exclusiveqi = 2657,
  CODE_FOR_arm_load_acquire_exclusivehi = 2658,
  CODE_FOR_arm_load_exclusivesi = 2659,
  CODE_FOR_arm_load_acquire_exclusivesi = 2660,
  CODE_FOR_arm_load_exclusivedi = 2661,
   CODE_FOR_arm_load_acquire_exclusivedi = CODE_FOR_nothing,
  CODE_FOR_arm_store_exclusiveqi = 2662,
  CODE_FOR_arm_store_exclusivehi = 2663,
  CODE_FOR_arm_store_exclusivesi = 2664,
   CODE_FOR_arm_store_exclusivedi = CODE_FOR_nothing,
   CODE_FOR_arm_store_release_exclusivedi = CODE_FOR_nothing,
  CODE_FOR_arm_store_release_exclusiveqi = 2665,
  CODE_FOR_arm_store_release_exclusivehi = 2666,
  CODE_FOR_arm_store_release_exclusivesi = 2667,
  CODE_FOR_addqq3 = 2668,
  CODE_FOR_addhq3 = 2669,
  CODE_FOR_addsq3 = 2670,
  CODE_FOR_adduqq3 = 2671,
  CODE_FOR_adduhq3 = 2672,
  CODE_FOR_addusq3 = 2673,
  CODE_FOR_addha3 = 2674,
  CODE_FOR_addsa3 = 2675,
  CODE_FOR_adduha3 = 2676,
  CODE_FOR_addusa3 = 2677,
  CODE_FOR_addv4qq3 = 2678,
  CODE_FOR_addv2hq3 = 2679,
  CODE_FOR_addv2ha3 = 2680,
  CODE_FOR_usaddv4uqq3 = 2681,
  CODE_FOR_usaddv2uhq3 = 2682,
  CODE_FOR_usadduqq3 = 2683,
  CODE_FOR_usadduhq3 = 2684,
  CODE_FOR_usaddv2uha3 = 2685,
  CODE_FOR_usadduha3 = 2686,
  CODE_FOR_ssaddv4qq3 = 2687,
  CODE_FOR_ssaddv2hq3 = 2688,
  CODE_FOR_ssaddqq3 = 2689,
  CODE_FOR_ssaddhq3 = 2690,
  CODE_FOR_ssaddv2ha3 = 2691,
  CODE_FOR_ssaddha3 = 2692,
  CODE_FOR_ssaddsq3 = 2693,
  CODE_FOR_ssaddsa3 = 2694,
  CODE_FOR_subqq3 = 2695,
  CODE_FOR_subhq3 = 2696,
  CODE_FOR_subsq3 = 2697,
  CODE_FOR_subuqq3 = 2698,
  CODE_FOR_subuhq3 = 2699,
  CODE_FOR_subusq3 = 2700,
  CODE_FOR_subha3 = 2701,
  CODE_FOR_subsa3 = 2702,
  CODE_FOR_subuha3 = 2703,
  CODE_FOR_subusa3 = 2704,
  CODE_FOR_subv4qq3 = 2705,
  CODE_FOR_subv2hq3 = 2706,
  CODE_FOR_subv2ha3 = 2707,
  CODE_FOR_ussubv4uqq3 = 2708,
  CODE_FOR_ussubv2uhq3 = 2709,
  CODE_FOR_ussubuqq3 = 2710,
  CODE_FOR_ussubuhq3 = 2711,
  CODE_FOR_ussubv2uha3 = 2712,
  CODE_FOR_ussubuha3 = 2713,
  CODE_FOR_sssubv4qq3 = 2714,
  CODE_FOR_sssubv2hq3 = 2715,
  CODE_FOR_sssubqq3 = 2716,
  CODE_FOR_sssubhq3 = 2717,
  CODE_FOR_sssubv2ha3 = 2718,
  CODE_FOR_sssubha3 = 2719,
  CODE_FOR_sssubsq3 = 2720,
  CODE_FOR_sssubsa3 = 2721,
  CODE_FOR_ssmulsa3 = 2722,
  CODE_FOR_usmulusa3 = 2723,
  CODE_FOR_arm_ssatsihi_shift = 2724,
  CODE_FOR_arm_usatsihi = 2725,
  CODE_FOR_adddi3 = 2726,
  CODE_FOR_addvsi4 = 2727,
  CODE_FOR_addvdi4 = 2728,
  CODE_FOR_uaddvsi4 = 2729,
  CODE_FOR_uaddvdi4 = 2730,
  CODE_FOR_addsi3 = 2731,
  CODE_FOR_subvsi4 = 2732,
  CODE_FOR_subvdi4 = 2733,
  CODE_FOR_usubvsi4 = 2734,
  CODE_FOR_usubvdi4 = 2735,
  CODE_FOR_addsf3 = 2736,
  CODE_FOR_adddf3 = 2737,
  CODE_FOR_subdi3 = 2738,
  CODE_FOR_subsi3 = 2739,
  CODE_FOR_subsf3 = 2740,
  CODE_FOR_subdf3 = 2741,
  CODE_FOR_mulhi3 = 2742,
  CODE_FOR_mulsi3 = 2743,
  CODE_FOR_maddsidi4 = 2744,
  CODE_FOR_mulsidi3 = 2745,
  CODE_FOR_umulsidi3 = 2746,
  CODE_FOR_umaddsidi4 = 2747,
  CODE_FOR_smulsi3_highpart = 2748,
  CODE_FOR_umulsi3_highpart = 2749,
  CODE_FOR_mulsf3 = 2750,
  CODE_FOR_muldf3 = 2751,
  CODE_FOR_divsf3 = 2752,
  CODE_FOR_divdf3 = 2753,
  CODE_FOR_anddi3 = 2754,
  CODE_FOR_andsi3 = 2755,
  CODE_FOR_insv = 2756,
  CODE_FOR_iordi3 = 2757,
  CODE_FOR_iorsi3 = 2758,
  CODE_FOR_xordi3 = 2759,
  CODE_FOR_xorsi3 = 2760,
  CODE_FOR_smaxsi3 = 2761,
  CODE_FOR_sminsi3 = 2762,
  CODE_FOR_umaxsi3 = 2763,
  CODE_FOR_uminsi3 = 2764,
  CODE_FOR_ashldi3 = 2765,
  CODE_FOR_ashlsi3 = 2766,
  CODE_FOR_ashrdi3 = 2767,
  CODE_FOR_ashrsi3 = 2768,
  CODE_FOR_lshrdi3 = 2769,
  CODE_FOR_lshrsi3 = 2770,
  CODE_FOR_rotlsi3 = 2771,
  CODE_FOR_rotrsi3 = 2772,
  CODE_FOR_extzv = 2773,
  CODE_FOR_extzv_t1 = 2774,
  CODE_FOR_extv = 2775,
  CODE_FOR_extv_regsi = 2776,
  CODE_FOR_negvsi3 = 2777,
  CODE_FOR_negvdi3 = 2778,
  CODE_FOR_negdi2 = 2779,
  CODE_FOR_negsi2 = 2780,
  CODE_FOR_negsf2 = 2781,
  CODE_FOR_negdf2 = 2782,
  CODE_FOR_abssi2 = 2783,
  CODE_FOR_abssf2 = 2784,
  CODE_FOR_absdf2 = 2785,
  CODE_FOR_sqrtsf2 = 2786,
  CODE_FOR_sqrtdf2 = 2787,
  CODE_FOR_one_cmpldi2 = 2788,
  CODE_FOR_one_cmplsi2 = 2789,
  CODE_FOR_floatsihf2 = 2790,
  CODE_FOR_floatdihf2 = 2791,
  CODE_FOR_floatsisf2 = 2792,
  CODE_FOR_floatsidf2 = 2793,
  CODE_FOR_fix_trunchfsi2 = 2794,
  CODE_FOR_fix_trunchfdi2 = 2795,
  CODE_FOR_fix_truncsfsi2 = 2796,
  CODE_FOR_fix_truncdfsi2 = 2797,
  CODE_FOR_truncdfsf2 = 2798,
  CODE_FOR_truncdfhf2 = 2799,
  CODE_FOR_zero_extendhisi2 = 2800,
  CODE_FOR_zero_extendqisi2 = 2801,
  CODE_FOR_extendhisi2 = 2802,
  CODE_FOR_extendhisi2_mem = 2803,
  CODE_FOR_extendqihi2 = 2804,
  CODE_FOR_extendqisi2 = 2805,
  CODE_FOR_extendsfdf2 = 2806,
  CODE_FOR_extendhfdf2 = 2807,
  CODE_FOR_movdi = 2808,
  CODE_FOR_movsi = 2809,
  CODE_FOR_calculate_pic_address = 2810,
  CODE_FOR_builtin_setjmp_receiver = 2811,
  CODE_FOR_storehi = 2812,
  CODE_FOR_storehi_bigend = 2813,
  CODE_FOR_storeinthi = 2814,
  CODE_FOR_storehi_single_op = 2815,
  CODE_FOR_movhi = 2816,
  CODE_FOR_movhi_bytes = 2817,
  CODE_FOR_movhi_bigend = 2818,
  CODE_FOR_reload_outhi = 2819,
  CODE_FOR_reload_inhi = 2820,
  CODE_FOR_movqi = 2821,
  CODE_FOR_movhf = 2822,
  CODE_FOR_movsf = 2823,
  CODE_FOR_movdf = 2824,
  CODE_FOR_reload_outdf = 2825,
  CODE_FOR_load_multiple = 2826,
  CODE_FOR_store_multiple = 2827,
  CODE_FOR_setmemsi = 2828,
  CODE_FOR_movmemqi = 2829,
  CODE_FOR_cbranchsi4 = 2830,
  CODE_FOR_cbranchsf4 = 2831,
  CODE_FOR_cbranchdf4 = 2832,
  CODE_FOR_cbranchdi4 = 2833,
  CODE_FOR_cbranch_cc = 2834,
  CODE_FOR_cstore_cc = 2835,
  CODE_FOR_cstoresi4 = 2836,
  CODE_FOR_cstorehf4 = 2837,
  CODE_FOR_cstoresf4 = 2838,
  CODE_FOR_cstoredf4 = 2839,
  CODE_FOR_cstoredi4 = 2840,
  CODE_FOR_movsicc = 2841,
  CODE_FOR_movhfcc = 2842,
  CODE_FOR_movsfcc = 2843,
  CODE_FOR_movdfcc = 2844,
  CODE_FOR_jump = 2845,
  CODE_FOR_call = 2846,
  CODE_FOR_call_internal = 2847,
  CODE_FOR_nonsecure_call_internal = 2848,
  CODE_FOR_call_value = 2849,
  CODE_FOR_call_value_internal = 2850,
  CODE_FOR_nonsecure_call_value_internal = 2851,
  CODE_FOR_sibcall_internal = 2852,
  CODE_FOR_sibcall = 2853,
  CODE_FOR_sibcall_value_internal = 2854,
  CODE_FOR_sibcall_value = 2855,
  CODE_FOR_return = 2856,
  CODE_FOR_simple_return = 2857,
  CODE_FOR_return_addr_mask = 2858,
  CODE_FOR_untyped_call = 2859,
  CODE_FOR_untyped_return = 2860,
  CODE_FOR_casesi = 2861,
  CODE_FOR_indirect_jump = 2862,
  CODE_FOR_prologue = 2863,
  CODE_FOR_epilogue = 2864,
  CODE_FOR_sibcall_epilogue = 2865,
  CODE_FOR_eh_epilogue = 2866,
  CODE_FOR_eh_return = 2867,
  CODE_FOR_get_thread_pointersi = 2868,
  CODE_FOR_arm_legacy_rev = 2869,
  CODE_FOR_thumb_legacy_rev = 2870,
  CODE_FOR_modsi3 = 2871,
  CODE_FOR_bswapsi2 = 2872,
  CODE_FOR_bswaphi2 = 2873,
  CODE_FOR_copysignsf3 = 2874,
  CODE_FOR_copysigndf3 = 2875,
  CODE_FOR_movmisalignhi = 2876,
  CODE_FOR_movmisalignsi = 2877,
  CODE_FOR_ldc = 2878,
  CODE_FOR_ldc2 = 2879,
  CODE_FOR_ldcl = 2880,
  CODE_FOR_ldc2l = 2881,
  CODE_FOR_stc = 2882,
  CODE_FOR_stc2 = 2883,
  CODE_FOR_stcl = 2884,
  CODE_FOR_stc2l = 2885,
  CODE_FOR_movv2di = 2886,
  CODE_FOR_movv2si = 2887,
  CODE_FOR_movv4hi = 2888,
  CODE_FOR_movv8qi = 2889,
  CODE_FOR_movv2sf = 2890,
  CODE_FOR_movv4si = 2891,
  CODE_FOR_movv8hi = 2892,
  CODE_FOR_movv16qi = 2893,
  CODE_FOR_movv4sf = 2894,
  CODE_FOR_addv2di3 = 2895,
  CODE_FOR_addv2si3 = 2896,
  CODE_FOR_addv4hi3 = 2897,
  CODE_FOR_addv8qi3 = 2898,
  CODE_FOR_addv2sf3 = 2899,
  CODE_FOR_addv4si3 = 2900,
  CODE_FOR_addv8hi3 = 2901,
  CODE_FOR_addv16qi3 = 2902,
  CODE_FOR_addv4sf3 = 2903,
  CODE_FOR_subv2di3 = 2904,
  CODE_FOR_subv2si3 = 2905,
  CODE_FOR_subv4hi3 = 2906,
  CODE_FOR_subv8qi3 = 2907,
  CODE_FOR_subv2sf3 = 2908,
  CODE_FOR_subv4si3 = 2909,
  CODE_FOR_subv8hi3 = 2910,
  CODE_FOR_subv16qi3 = 2911,
  CODE_FOR_subv4sf3 = 2912,
  CODE_FOR_mulv2si3 = 2913,
  CODE_FOR_mulv4hi3 = 2914,
  CODE_FOR_mulv8qi3 = 2915,
  CODE_FOR_mulv2sf3 = 2916,
  CODE_FOR_mulv4si3 = 2917,
  CODE_FOR_mulv8hi3 = 2918,
  CODE_FOR_mulv16qi3 = 2919,
  CODE_FOR_mulv4sf3 = 2920,
  CODE_FOR_sminv2si3 = 2921,
  CODE_FOR_sminv4hi3 = 2922,
  CODE_FOR_sminv8qi3 = 2923,
  CODE_FOR_sminv2sf3 = 2924,
  CODE_FOR_sminv4si3 = 2925,
  CODE_FOR_sminv8hi3 = 2926,
  CODE_FOR_sminv16qi3 = 2927,
  CODE_FOR_sminv4sf3 = 2928,
  CODE_FOR_uminv2si3 = 2929,
  CODE_FOR_uminv4hi3 = 2930,
  CODE_FOR_uminv8qi3 = 2931,
  CODE_FOR_uminv4si3 = 2932,
  CODE_FOR_uminv8hi3 = 2933,
  CODE_FOR_uminv16qi3 = 2934,
  CODE_FOR_smaxv2si3 = 2935,
  CODE_FOR_smaxv4hi3 = 2936,
  CODE_FOR_smaxv8qi3 = 2937,
  CODE_FOR_smaxv2sf3 = 2938,
  CODE_FOR_smaxv4si3 = 2939,
  CODE_FOR_smaxv8hi3 = 2940,
  CODE_FOR_smaxv16qi3 = 2941,
  CODE_FOR_smaxv4sf3 = 2942,
  CODE_FOR_umaxv2si3 = 2943,
  CODE_FOR_umaxv4hi3 = 2944,
  CODE_FOR_umaxv8qi3 = 2945,
  CODE_FOR_umaxv4si3 = 2946,
  CODE_FOR_umaxv8hi3 = 2947,
  CODE_FOR_umaxv16qi3 = 2948,
  CODE_FOR_vec_permv8qi = 2949,
  CODE_FOR_vec_permv16qi = 2950,
  CODE_FOR_iwmmxt_setwcgr0 = 2951,
  CODE_FOR_iwmmxt_setwcgr1 = 2952,
  CODE_FOR_iwmmxt_setwcgr2 = 2953,
  CODE_FOR_iwmmxt_setwcgr3 = 2954,
  CODE_FOR_iwmmxt_getwcgr0 = 2955,
  CODE_FOR_iwmmxt_getwcgr1 = 2956,
  CODE_FOR_iwmmxt_getwcgr2 = 2957,
  CODE_FOR_iwmmxt_getwcgr3 = 2958,
  CODE_FOR_neon_vabshf = 2959,
  CODE_FOR_neon_vfmahf = 2960,
  CODE_FOR_neon_vfmshf = 2961,
  CODE_FOR_neon_vcvths_nhf = 2962,
  CODE_FOR_neon_vcvthu_nhf = 2963,
  CODE_FOR_neon_vcvths_nsi = 2964,
  CODE_FOR_neon_vcvthu_nsi = 2965,
  CODE_FOR_thumb_movhi_clobber = 2966,
  CODE_FOR_cbranchqi4 = 2967,
  CODE_FOR_cstoresi_eq0_thumb1 = 2968,
  CODE_FOR_cstoresi_ne0_thumb1 = 2969,
  CODE_FOR_thumb1_casesi_internal_pic = 2970,
  CODE_FOR_tablejump = 2971,
  CODE_FOR_doloop_end = 2972,
  CODE_FOR_movti = 2973,
  CODE_FOR_movei = 2974,
  CODE_FOR_movoi = 2975,
  CODE_FOR_movci = 2976,
  CODE_FOR_movxi = 2977,
  CODE_FOR_movv4hf = 2978,
  CODE_FOR_movv8hf = 2979,
  CODE_FOR_movmisalignv8qi = 2980,
  CODE_FOR_movmisalignv16qi = 2981,
  CODE_FOR_movmisalignv4hi = 2982,
  CODE_FOR_movmisalignv8hi = 2983,
  CODE_FOR_movmisalignv2si = 2984,
  CODE_FOR_movmisalignv4si = 2985,
  CODE_FOR_movmisalignv4hf = 2986,
  CODE_FOR_movmisalignv8hf = 2987,
  CODE_FOR_movmisalignv2sf = 2988,
  CODE_FOR_movmisalignv4sf = 2989,
  CODE_FOR_movmisaligndi = 2990,
  CODE_FOR_movmisalignv2di = 2991,
  CODE_FOR_vec_setv8qi = 2992,
  CODE_FOR_vec_setv16qi = 2993,
  CODE_FOR_vec_setv4hi = 2994,
  CODE_FOR_vec_setv8hi = 2995,
  CODE_FOR_vec_setv2si = 2996,
  CODE_FOR_vec_setv4si = 2997,
  CODE_FOR_vec_setv4hf = 2998,
  CODE_FOR_vec_setv8hf = 2999,
  CODE_FOR_vec_setv2sf = 3000,
  CODE_FOR_vec_setv4sf = 3001,
  CODE_FOR_vec_setv2di = 3002,
  CODE_FOR_vec_initv8qiqi = 3003,
  CODE_FOR_vec_initv16qiqi = 3004,
  CODE_FOR_vec_initv4hihi = 3005,
  CODE_FOR_vec_initv8hihi = 3006,
  CODE_FOR_vec_initv2sisi = 3007,
  CODE_FOR_vec_initv4sisi = 3008,
  CODE_FOR_vec_initv4hfhf = 3009,
  CODE_FOR_vec_initv8hfhf = 3010,
  CODE_FOR_vec_initv2sfsf = 3011,
  CODE_FOR_vec_initv4sfsf = 3012,
  CODE_FOR_vec_initv2didi = 3013,
  CODE_FOR_neon_vabsv8hf = 3014,
  CODE_FOR_neon_vnegv8hf = 3015,
  CODE_FOR_neon_vabsv4hf = 3016,
  CODE_FOR_neon_vnegv4hf = 3017,
  CODE_FOR_vashrv8qi3 = 3018,
  CODE_FOR_vashrv16qi3 = 3019,
  CODE_FOR_vashrv4hi3 = 3020,
  CODE_FOR_vashrv8hi3 = 3021,
  CODE_FOR_vashrv2si3 = 3022,
  CODE_FOR_vashrv4si3 = 3023,
  CODE_FOR_vlshrv8qi3 = 3024,
  CODE_FOR_vlshrv16qi3 = 3025,
  CODE_FOR_vlshrv4hi3 = 3026,
  CODE_FOR_vlshrv8hi3 = 3027,
  CODE_FOR_vlshrv2si3 = 3028,
  CODE_FOR_vlshrv4si3 = 3029,
  CODE_FOR_widen_ssumv16qi3 = 3030,
  CODE_FOR_widen_ssumv8hi3 = 3031,
  CODE_FOR_widen_ssumv4si3 = 3032,
  CODE_FOR_widen_usumv16qi3 = 3033,
  CODE_FOR_widen_usumv8hi3 = 3034,
  CODE_FOR_widen_usumv4si3 = 3035,
  CODE_FOR_move_hi_quad_v2di = 3036,
  CODE_FOR_move_hi_quad_v2df = 3037,
  CODE_FOR_move_hi_quad_v16qi = 3038,
  CODE_FOR_move_hi_quad_v8hi = 3039,
  CODE_FOR_move_hi_quad_v4si = 3040,
  CODE_FOR_move_hi_quad_v4sf = 3041,
  CODE_FOR_move_lo_quad_v2di = 3042,
  CODE_FOR_move_lo_quad_v2df = 3043,
  CODE_FOR_move_lo_quad_v16qi = 3044,
  CODE_FOR_move_lo_quad_v8hi = 3045,
  CODE_FOR_move_lo_quad_v4si = 3046,
  CODE_FOR_move_lo_quad_v4sf = 3047,
  CODE_FOR_reduc_plus_scal_v8qi = 3048,
  CODE_FOR_reduc_plus_scal_v4hi = 3049,
  CODE_FOR_reduc_plus_scal_v2si = 3050,
  CODE_FOR_reduc_plus_scal_v2sf = 3051,
  CODE_FOR_reduc_plus_scal_v16qi = 3052,
  CODE_FOR_reduc_plus_scal_v8hi = 3053,
  CODE_FOR_reduc_plus_scal_v4si = 3054,
  CODE_FOR_reduc_plus_scal_v4sf = 3055,
  CODE_FOR_reduc_plus_scal_v2di = 3056,
  CODE_FOR_reduc_smin_scal_v8qi = 3057,
  CODE_FOR_reduc_smin_scal_v4hi = 3058,
  CODE_FOR_reduc_smin_scal_v2si = 3059,
  CODE_FOR_reduc_smin_scal_v2sf = 3060,
  CODE_FOR_reduc_smin_scal_v16qi = 3061,
  CODE_FOR_reduc_smin_scal_v8hi = 3062,
  CODE_FOR_reduc_smin_scal_v4si = 3063,
  CODE_FOR_reduc_smin_scal_v4sf = 3064,
  CODE_FOR_reduc_smax_scal_v8qi = 3065,
  CODE_FOR_reduc_smax_scal_v4hi = 3066,
  CODE_FOR_reduc_smax_scal_v2si = 3067,
  CODE_FOR_reduc_smax_scal_v2sf = 3068,
  CODE_FOR_reduc_smax_scal_v16qi = 3069,
  CODE_FOR_reduc_smax_scal_v8hi = 3070,
  CODE_FOR_reduc_smax_scal_v4si = 3071,
  CODE_FOR_reduc_smax_scal_v4sf = 3072,
  CODE_FOR_reduc_umin_scal_v8qi = 3073,
  CODE_FOR_reduc_umin_scal_v4hi = 3074,
  CODE_FOR_reduc_umin_scal_v2si = 3075,
  CODE_FOR_reduc_umin_scal_v16qi = 3076,
  CODE_FOR_reduc_umin_scal_v8hi = 3077,
  CODE_FOR_reduc_umin_scal_v4si = 3078,
  CODE_FOR_reduc_umax_scal_v8qi = 3079,
  CODE_FOR_reduc_umax_scal_v4hi = 3080,
  CODE_FOR_reduc_umax_scal_v2si = 3081,
  CODE_FOR_reduc_umax_scal_v16qi = 3082,
  CODE_FOR_reduc_umax_scal_v8hi = 3083,
  CODE_FOR_reduc_umax_scal_v4si = 3084,
  CODE_FOR_vcondv8qiv8qi = 3085,
  CODE_FOR_vcondv16qiv16qi = 3086,
  CODE_FOR_vcondv4hiv4hi = 3087,
  CODE_FOR_vcondv8hiv8hi = 3088,
  CODE_FOR_vcondv2siv2si = 3089,
  CODE_FOR_vcondv4siv4si = 3090,
  CODE_FOR_vcondv2sfv2sf = 3091,
  CODE_FOR_vcondv4sfv4sf = 3092,
  CODE_FOR_vconduv8qiv8qi = 3093,
  CODE_FOR_vconduv16qiv16qi = 3094,
  CODE_FOR_vconduv4hiv4hi = 3095,
  CODE_FOR_vconduv8hiv8hi = 3096,
  CODE_FOR_vconduv2siv2si = 3097,
  CODE_FOR_vconduv4siv4si = 3098,
  CODE_FOR_neon_vaddv2sf = 3099,
  CODE_FOR_neon_vaddv4sf = 3100,
  CODE_FOR_neon_vaddv8hf = 3101,
  CODE_FOR_neon_vaddv4hf = 3102,
  CODE_FOR_neon_vsubv8hf = 3103,
  CODE_FOR_neon_vsubv4hf = 3104,
  CODE_FOR_neon_vmlav8qi = 3105,
  CODE_FOR_neon_vmlav16qi = 3106,
  CODE_FOR_neon_vmlav4hi = 3107,
  CODE_FOR_neon_vmlav8hi = 3108,
  CODE_FOR_neon_vmlav2si = 3109,
  CODE_FOR_neon_vmlav4si = 3110,
  CODE_FOR_neon_vmlav2sf = 3111,
  CODE_FOR_neon_vmlav4sf = 3112,
  CODE_FOR_neon_vfmav2sf = 3113,
  CODE_FOR_neon_vfmav4sf = 3114,
  CODE_FOR_neon_vfmav8hf = 3115,
  CODE_FOR_neon_vfmav4hf = 3116,
  CODE_FOR_neon_vfmsv2sf = 3117,
  CODE_FOR_neon_vfmsv4sf = 3118,
  CODE_FOR_neon_vfmsv8hf = 3119,
  CODE_FOR_neon_vfmsv4hf = 3120,
  CODE_FOR_neon_vfmal_lowv2sf = 3121,
  CODE_FOR_neon_vfmal_highv2sf = 3122,
  CODE_FOR_neon_vfmsl_lowv2sf = 3123,
  CODE_FOR_neon_vfmsl_highv2sf = 3124,
  CODE_FOR_neon_vfmal_lowv4sf = 3125,
  CODE_FOR_neon_vfmal_highv4sf = 3126,
  CODE_FOR_neon_vfmsl_lowv4sf = 3127,
  CODE_FOR_neon_vfmsl_highv4sf = 3128,
  CODE_FOR_neon_vfmal_lane_lowv2sf = 3129,
  CODE_FOR_neon_vfmal_lane_highv2sf = 3130,
  CODE_FOR_neon_vfmsl_lane_lowv2sf = 3131,
  CODE_FOR_neon_vfmsl_lane_highv2sf = 3132,
  CODE_FOR_neon_vfmal_lane_lowv4sf = 3133,
  CODE_FOR_neon_vfmal_lane_highv4sf = 3134,
  CODE_FOR_neon_vfmsl_lane_lowv4sf = 3135,
  CODE_FOR_neon_vfmsl_lane_highv4sf = 3136,
  CODE_FOR_neon_vfmal_lane_lowv8hfv2sf = 3137,
  CODE_FOR_neon_vfmal_lane_highv8hfv2sf = 3138,
  CODE_FOR_neon_vfmsl_lane_lowv8hfv2sf = 3139,
  CODE_FOR_neon_vfmsl_lane_highv8hfv2sf = 3140,
  CODE_FOR_neon_vfmal_lane_lowv4hfv4sf = 3141,
  CODE_FOR_neon_vfmal_lane_highv4hfv4sf = 3142,
  CODE_FOR_neon_vfmsl_lane_lowv4hfv4sf = 3143,
  CODE_FOR_neon_vfmsl_lane_highv4hfv4sf = 3144,
  CODE_FOR_neon_vmlsv8qi = 3145,
  CODE_FOR_neon_vmlsv16qi = 3146,
  CODE_FOR_neon_vmlsv4hi = 3147,
  CODE_FOR_neon_vmlsv8hi = 3148,
  CODE_FOR_neon_vmlsv2si = 3149,
  CODE_FOR_neon_vmlsv4si = 3150,
  CODE_FOR_neon_vmlsv2sf = 3151,
  CODE_FOR_neon_vmlsv4sf = 3152,
  CODE_FOR_neon_vsubv2sf = 3153,
  CODE_FOR_neon_vsubv4sf = 3154,
  CODE_FOR_neon_vceqv8qi = 3155,
  CODE_FOR_neon_vcgtv8qi = 3156,
  CODE_FOR_neon_vcgev8qi = 3157,
  CODE_FOR_neon_vclev8qi = 3158,
  CODE_FOR_neon_vcltv8qi = 3159,
  CODE_FOR_neon_vceqv16qi = 3160,
  CODE_FOR_neon_vcgtv16qi = 3161,
  CODE_FOR_neon_vcgev16qi = 3162,
  CODE_FOR_neon_vclev16qi = 3163,
  CODE_FOR_neon_vcltv16qi = 3164,
  CODE_FOR_neon_vceqv4hi = 3165,
  CODE_FOR_neon_vcgtv4hi = 3166,
  CODE_FOR_neon_vcgev4hi = 3167,
  CODE_FOR_neon_vclev4hi = 3168,
  CODE_FOR_neon_vcltv4hi = 3169,
  CODE_FOR_neon_vceqv8hi = 3170,
  CODE_FOR_neon_vcgtv8hi = 3171,
  CODE_FOR_neon_vcgev8hi = 3172,
  CODE_FOR_neon_vclev8hi = 3173,
  CODE_FOR_neon_vcltv8hi = 3174,
  CODE_FOR_neon_vceqv2si = 3175,
  CODE_FOR_neon_vcgtv2si = 3176,
  CODE_FOR_neon_vcgev2si = 3177,
  CODE_FOR_neon_vclev2si = 3178,
  CODE_FOR_neon_vcltv2si = 3179,
  CODE_FOR_neon_vceqv4si = 3180,
  CODE_FOR_neon_vcgtv4si = 3181,
  CODE_FOR_neon_vcgev4si = 3182,
  CODE_FOR_neon_vclev4si = 3183,
  CODE_FOR_neon_vcltv4si = 3184,
  CODE_FOR_neon_vceqv2sf = 3185,
  CODE_FOR_neon_vcgtv2sf = 3186,
  CODE_FOR_neon_vcgev2sf = 3187,
  CODE_FOR_neon_vclev2sf = 3188,
  CODE_FOR_neon_vcltv2sf = 3189,
  CODE_FOR_neon_vceqv4sf = 3190,
  CODE_FOR_neon_vcgtv4sf = 3191,
  CODE_FOR_neon_vcgev4sf = 3192,
  CODE_FOR_neon_vclev4sf = 3193,
  CODE_FOR_neon_vcltv4sf = 3194,
  CODE_FOR_neon_vceqv8hf = 3195,
  CODE_FOR_neon_vcgtv8hf = 3196,
  CODE_FOR_neon_vcgev8hf = 3197,
  CODE_FOR_neon_vclev8hf = 3198,
  CODE_FOR_neon_vcltv8hf = 3199,
  CODE_FOR_neon_vceqv4hf = 3200,
  CODE_FOR_neon_vcgtv4hf = 3201,
  CODE_FOR_neon_vcgev4hf = 3202,
  CODE_FOR_neon_vclev4hf = 3203,
  CODE_FOR_neon_vcltv4hf = 3204,
  CODE_FOR_neon_vcagtv2sf = 3205,
  CODE_FOR_neon_vcagev2sf = 3206,
  CODE_FOR_neon_vcagtv4sf = 3207,
  CODE_FOR_neon_vcagev4sf = 3208,
  CODE_FOR_neon_vcagtv8hf = 3209,
  CODE_FOR_neon_vcagev8hf = 3210,
  CODE_FOR_neon_vcaltv8hf = 3211,
  CODE_FOR_neon_vcalev8hf = 3212,
  CODE_FOR_neon_vcagtv4hf = 3213,
  CODE_FOR_neon_vcagev4hf = 3214,
  CODE_FOR_neon_vcaltv4hf = 3215,
  CODE_FOR_neon_vcalev4hf = 3216,
  CODE_FOR_neon_vceqzv8hf = 3217,
  CODE_FOR_neon_vcgtzv8hf = 3218,
  CODE_FOR_neon_vcgezv8hf = 3219,
  CODE_FOR_neon_vclezv8hf = 3220,
  CODE_FOR_neon_vcltzv8hf = 3221,
  CODE_FOR_neon_vceqzv4hf = 3222,
  CODE_FOR_neon_vcgtzv4hf = 3223,
  CODE_FOR_neon_vcgezv4hf = 3224,
  CODE_FOR_neon_vclezv4hf = 3225,
  CODE_FOR_neon_vcltzv4hf = 3226,
  CODE_FOR_neon_vpaddv8qi = 3227,
  CODE_FOR_neon_vpaddv4hi = 3228,
  CODE_FOR_neon_vpaddv2si = 3229,
  CODE_FOR_neon_vpaddv2sf = 3230,
  CODE_FOR_neon_vabsv8qi = 3231,
  CODE_FOR_neon_vabsv16qi = 3232,
  CODE_FOR_neon_vabsv4hi = 3233,
  CODE_FOR_neon_vabsv8hi = 3234,
  CODE_FOR_neon_vabsv2si = 3235,
  CODE_FOR_neon_vabsv4si = 3236,
  CODE_FOR_neon_vabsv2sf = 3237,
  CODE_FOR_neon_vabsv4sf = 3238,
  CODE_FOR_neon_vnegv8qi = 3239,
  CODE_FOR_neon_vnegv16qi = 3240,
  CODE_FOR_neon_vnegv4hi = 3241,
  CODE_FOR_neon_vnegv8hi = 3242,
  CODE_FOR_neon_vnegv2si = 3243,
  CODE_FOR_neon_vnegv4si = 3244,
  CODE_FOR_neon_vnegv2sf = 3245,
  CODE_FOR_neon_vnegv4sf = 3246,
  CODE_FOR_sdot_prodv8qi = 3247,
  CODE_FOR_udot_prodv8qi = 3248,
  CODE_FOR_sdot_prodv16qi = 3249,
  CODE_FOR_udot_prodv16qi = 3250,
  CODE_FOR_neon_copysignfv2sf = 3251,
  CODE_FOR_neon_copysignfv4sf = 3252,
  CODE_FOR_neon_vclzv8qi = 3253,
  CODE_FOR_neon_vclzv16qi = 3254,
  CODE_FOR_neon_vclzv4hi = 3255,
  CODE_FOR_neon_vclzv8hi = 3256,
  CODE_FOR_neon_vclzv2si = 3257,
  CODE_FOR_neon_vclzv4si = 3258,
  CODE_FOR_neon_vcntv8qi = 3259,
  CODE_FOR_neon_vcntv16qi = 3260,
  CODE_FOR_neon_vmvnv8qi = 3261,
  CODE_FOR_neon_vmvnv16qi = 3262,
  CODE_FOR_neon_vmvnv4hi = 3263,
  CODE_FOR_neon_vmvnv8hi = 3264,
  CODE_FOR_neon_vmvnv2si = 3265,
  CODE_FOR_neon_vmvnv4si = 3266,
  CODE_FOR_neon_vget_lanev8qi = 3267,
  CODE_FOR_neon_vget_lanev16qi = 3268,
  CODE_FOR_neon_vget_lanev4hi = 3269,
  CODE_FOR_neon_vget_lanev8hi = 3270,
  CODE_FOR_neon_vget_lanev2si = 3271,
  CODE_FOR_neon_vget_lanev4si = 3272,
  CODE_FOR_neon_vget_lanev2sf = 3273,
  CODE_FOR_neon_vget_lanev4sf = 3274,
  CODE_FOR_neon_vget_laneuv8qi = 3275,
  CODE_FOR_neon_vget_laneuv16qi = 3276,
  CODE_FOR_neon_vget_laneuv4hi = 3277,
  CODE_FOR_neon_vget_laneuv8hi = 3278,
  CODE_FOR_neon_vget_laneuv2si = 3279,
  CODE_FOR_neon_vget_laneuv4si = 3280,
  CODE_FOR_neon_vget_lanedi = 3281,
  CODE_FOR_neon_vget_lanev2di = 3282,
  CODE_FOR_neon_vset_lanev8qi = 3283,
  CODE_FOR_neon_vset_lanev16qi = 3284,
  CODE_FOR_neon_vset_lanev4hi = 3285,
  CODE_FOR_neon_vset_lanev8hi = 3286,
  CODE_FOR_neon_vset_lanev2si = 3287,
  CODE_FOR_neon_vset_lanev4si = 3288,
  CODE_FOR_neon_vset_lanev4hf = 3289,
  CODE_FOR_neon_vset_lanev8hf = 3290,
  CODE_FOR_neon_vset_lanev2sf = 3291,
  CODE_FOR_neon_vset_lanev4sf = 3292,
  CODE_FOR_neon_vset_lanev2di = 3293,
  CODE_FOR_neon_vset_lanedi = 3294,
  CODE_FOR_neon_vcreatev8qi = 3295,
  CODE_FOR_neon_vcreatev4hi = 3296,
  CODE_FOR_neon_vcreatev2si = 3297,
  CODE_FOR_neon_vcreatev2sf = 3298,
  CODE_FOR_neon_vcreatedi = 3299,
  CODE_FOR_neon_vdup_ndi = 3300,
  CODE_FOR_neon_vdup_lanev8qi = 3301,
  CODE_FOR_neon_vdup_lanev16qi = 3302,
  CODE_FOR_neon_vdup_lanev4hi = 3303,
  CODE_FOR_neon_vdup_lanev8hi = 3304,
  CODE_FOR_neon_vdup_lanev2si = 3305,
  CODE_FOR_neon_vdup_lanev4si = 3306,
  CODE_FOR_neon_vdup_lanev2sf = 3307,
  CODE_FOR_neon_vdup_lanev4sf = 3308,
  CODE_FOR_neon_vdup_lanev8hf = 3309,
  CODE_FOR_neon_vdup_lanev4hf = 3310,
  CODE_FOR_neon_vdup_lanedi = 3311,
  CODE_FOR_neon_vdup_lanev2di = 3312,
  CODE_FOR_neon_vget_highv16qi = 3313,
  CODE_FOR_neon_vget_highv8hi = 3314,
  CODE_FOR_neon_vget_highv8hf = 3315,
  CODE_FOR_neon_vget_highv4si = 3316,
  CODE_FOR_neon_vget_highv4sf = 3317,
  CODE_FOR_neon_vget_highv2di = 3318,
  CODE_FOR_neon_vget_lowv16qi = 3319,
  CODE_FOR_neon_vget_lowv8hi = 3320,
  CODE_FOR_neon_vget_lowv8hf = 3321,
  CODE_FOR_neon_vget_lowv4si = 3322,
  CODE_FOR_neon_vget_lowv4sf = 3323,
  CODE_FOR_neon_vget_lowv2di = 3324,
  CODE_FOR_neon_vmul_nv4hi = 3325,
  CODE_FOR_neon_vmul_nv2si = 3326,
  CODE_FOR_neon_vmul_nv2sf = 3327,
  CODE_FOR_neon_vmul_nv8hi = 3328,
  CODE_FOR_neon_vmul_nv4si = 3329,
  CODE_FOR_neon_vmul_nv4sf = 3330,
  CODE_FOR_neon_vmul_nv8hf = 3331,
  CODE_FOR_neon_vmul_nv4hf = 3332,
  CODE_FOR_neon_vmulls_nv4hi = 3333,
  CODE_FOR_neon_vmulls_nv2si = 3334,
  CODE_FOR_neon_vmullu_nv4hi = 3335,
  CODE_FOR_neon_vmullu_nv2si = 3336,
  CODE_FOR_neon_vqdmull_nv4hi = 3337,
  CODE_FOR_neon_vqdmull_nv2si = 3338,
  CODE_FOR_neon_vqdmulh_nv4hi = 3339,
  CODE_FOR_neon_vqdmulh_nv2si = 3340,
  CODE_FOR_neon_vqrdmulh_nv4hi = 3341,
  CODE_FOR_neon_vqrdmulh_nv2si = 3342,
  CODE_FOR_neon_vqdmulh_nv8hi = 3343,
  CODE_FOR_neon_vqdmulh_nv4si = 3344,
  CODE_FOR_neon_vqrdmulh_nv8hi = 3345,
  CODE_FOR_neon_vqrdmulh_nv4si = 3346,
  CODE_FOR_neon_vmla_nv4hi = 3347,
  CODE_FOR_neon_vmla_nv2si = 3348,
  CODE_FOR_neon_vmla_nv2sf = 3349,
  CODE_FOR_neon_vmla_nv8hi = 3350,
  CODE_FOR_neon_vmla_nv4si = 3351,
  CODE_FOR_neon_vmla_nv4sf = 3352,
  CODE_FOR_neon_vmlals_nv4hi = 3353,
  CODE_FOR_neon_vmlals_nv2si = 3354,
  CODE_FOR_neon_vmlalu_nv4hi = 3355,
  CODE_FOR_neon_vmlalu_nv2si = 3356,
  CODE_FOR_neon_vqdmlal_nv4hi = 3357,
  CODE_FOR_neon_vqdmlal_nv2si = 3358,
  CODE_FOR_neon_vmls_nv4hi = 3359,
  CODE_FOR_neon_vmls_nv2si = 3360,
  CODE_FOR_neon_vmls_nv2sf = 3361,
  CODE_FOR_neon_vmls_nv8hi = 3362,
  CODE_FOR_neon_vmls_nv4si = 3363,
  CODE_FOR_neon_vmls_nv4sf = 3364,
  CODE_FOR_neon_vmlsls_nv4hi = 3365,
  CODE_FOR_neon_vmlsls_nv2si = 3366,
  CODE_FOR_neon_vmlslu_nv4hi = 3367,
  CODE_FOR_neon_vmlslu_nv2si = 3368,
  CODE_FOR_neon_vqdmlsl_nv4hi = 3369,
  CODE_FOR_neon_vqdmlsl_nv2si = 3370,
  CODE_FOR_neon_vbslv8qi = 3371,
  CODE_FOR_neon_vbslv16qi = 3372,
  CODE_FOR_neon_vbslv4hi = 3373,
  CODE_FOR_neon_vbslv8hi = 3374,
  CODE_FOR_neon_vbslv2si = 3375,
  CODE_FOR_neon_vbslv4si = 3376,
  CODE_FOR_neon_vbslv4hf = 3377,
  CODE_FOR_neon_vbslv8hf = 3378,
  CODE_FOR_neon_vbslv2sf = 3379,
  CODE_FOR_neon_vbslv4sf = 3380,
  CODE_FOR_neon_vbsldi = 3381,
  CODE_FOR_neon_vbslv2di = 3382,
  CODE_FOR_neon_vtrnv8qi_internal = 3383,
  CODE_FOR_neon_vtrnv16qi_internal = 3384,
  CODE_FOR_neon_vtrnv4hi_internal = 3385,
  CODE_FOR_neon_vtrnv8hi_internal = 3386,
  CODE_FOR_neon_vtrnv2si_internal = 3387,
  CODE_FOR_neon_vtrnv4si_internal = 3388,
  CODE_FOR_neon_vtrnv2sf_internal = 3389,
  CODE_FOR_neon_vtrnv4sf_internal = 3390,
  CODE_FOR_neon_vtrnv8hf_internal = 3391,
  CODE_FOR_neon_vtrnv4hf_internal = 3392,
  CODE_FOR_neon_vzipv8qi_internal = 3393,
  CODE_FOR_neon_vzipv16qi_internal = 3394,
  CODE_FOR_neon_vzipv4hi_internal = 3395,
  CODE_FOR_neon_vzipv8hi_internal = 3396,
  CODE_FOR_neon_vzipv2si_internal = 3397,
  CODE_FOR_neon_vzipv4si_internal = 3398,
  CODE_FOR_neon_vzipv2sf_internal = 3399,
  CODE_FOR_neon_vzipv4sf_internal = 3400,
  CODE_FOR_neon_vzipv8hf_internal = 3401,
  CODE_FOR_neon_vzipv4hf_internal = 3402,
  CODE_FOR_neon_vuzpv8qi_internal = 3403,
  CODE_FOR_neon_vuzpv16qi_internal = 3404,
  CODE_FOR_neon_vuzpv4hi_internal = 3405,
  CODE_FOR_neon_vuzpv8hi_internal = 3406,
  CODE_FOR_neon_vuzpv2si_internal = 3407,
  CODE_FOR_neon_vuzpv4si_internal = 3408,
  CODE_FOR_neon_vuzpv2sf_internal = 3409,
  CODE_FOR_neon_vuzpv4sf_internal = 3410,
  CODE_FOR_neon_vuzpv8hf_internal = 3411,
  CODE_FOR_neon_vuzpv4hf_internal = 3412,
  CODE_FOR_vec_load_lanesv8qiv8qi = 3413,
  CODE_FOR_vec_load_lanesv16qiv16qi = 3414,
  CODE_FOR_vec_load_lanesv4hiv4hi = 3415,
  CODE_FOR_vec_load_lanesv8hiv8hi = 3416,
  CODE_FOR_vec_load_lanesv2siv2si = 3417,
  CODE_FOR_vec_load_lanesv4siv4si = 3418,
  CODE_FOR_vec_load_lanesv4hfv4hf = 3419,
  CODE_FOR_vec_load_lanesv8hfv8hf = 3420,
  CODE_FOR_vec_load_lanesv2sfv2sf = 3421,
  CODE_FOR_vec_load_lanesv4sfv4sf = 3422,
  CODE_FOR_vec_load_lanesdidi = 3423,
  CODE_FOR_vec_load_lanesv2div2di = 3424,
  CODE_FOR_neon_vld1_dupdi = 3425,
  CODE_FOR_vec_store_lanesv8qiv8qi = 3426,
  CODE_FOR_vec_store_lanesv16qiv16qi = 3427,
  CODE_FOR_vec_store_lanesv4hiv4hi = 3428,
  CODE_FOR_vec_store_lanesv8hiv8hi = 3429,
  CODE_FOR_vec_store_lanesv2siv2si = 3430,
  CODE_FOR_vec_store_lanesv4siv4si = 3431,
  CODE_FOR_vec_store_lanesv4hfv4hf = 3432,
  CODE_FOR_vec_store_lanesv8hfv8hf = 3433,
  CODE_FOR_vec_store_lanesv2sfv2sf = 3434,
  CODE_FOR_vec_store_lanesv4sfv4sf = 3435,
  CODE_FOR_vec_store_lanesdidi = 3436,
  CODE_FOR_vec_store_lanesv2div2di = 3437,
  CODE_FOR_vec_load_lanestiv8qi = 3438,
  CODE_FOR_vec_load_lanestiv4hi = 3439,
  CODE_FOR_vec_load_lanestiv4hf = 3440,
  CODE_FOR_vec_load_lanestiv2si = 3441,
  CODE_FOR_vec_load_lanestiv2sf = 3442,
  CODE_FOR_vec_load_lanestidi = 3443,
  CODE_FOR_vec_load_lanesoiv16qi = 3444,
  CODE_FOR_vec_load_lanesoiv8hi = 3445,
  CODE_FOR_vec_load_lanesoiv8hf = 3446,
  CODE_FOR_vec_load_lanesoiv4si = 3447,
  CODE_FOR_vec_load_lanesoiv4sf = 3448,
  CODE_FOR_vec_store_lanestiv8qi = 3449,
  CODE_FOR_vec_store_lanestiv4hi = 3450,
  CODE_FOR_vec_store_lanestiv4hf = 3451,
  CODE_FOR_vec_store_lanestiv2si = 3452,
  CODE_FOR_vec_store_lanestiv2sf = 3453,
  CODE_FOR_vec_store_lanestidi = 3454,
  CODE_FOR_vec_store_lanesoiv16qi = 3455,
  CODE_FOR_vec_store_lanesoiv8hi = 3456,
  CODE_FOR_vec_store_lanesoiv8hf = 3457,
  CODE_FOR_vec_store_lanesoiv4si = 3458,
  CODE_FOR_vec_store_lanesoiv4sf = 3459,
  CODE_FOR_vec_load_laneseiv8qi = 3460,
  CODE_FOR_vec_load_laneseiv4hi = 3461,
  CODE_FOR_vec_load_laneseiv4hf = 3462,
  CODE_FOR_vec_load_laneseiv2si = 3463,
  CODE_FOR_vec_load_laneseiv2sf = 3464,
  CODE_FOR_vec_load_laneseidi = 3465,
  CODE_FOR_vec_load_lanesciv16qi = 3466,
  CODE_FOR_vec_load_lanesciv8hi = 3467,
  CODE_FOR_vec_load_lanesciv8hf = 3468,
  CODE_FOR_vec_load_lanesciv4si = 3469,
  CODE_FOR_vec_load_lanesciv4sf = 3470,
  CODE_FOR_neon_vld3v16qi = 3471,
  CODE_FOR_neon_vld3v8hi = 3472,
  CODE_FOR_neon_vld3v8hf = 3473,
  CODE_FOR_neon_vld3v4si = 3474,
  CODE_FOR_neon_vld3v4sf = 3475,
  CODE_FOR_vec_store_laneseiv8qi = 3476,
  CODE_FOR_vec_store_laneseiv4hi = 3477,
  CODE_FOR_vec_store_laneseiv4hf = 3478,
  CODE_FOR_vec_store_laneseiv2si = 3479,
  CODE_FOR_vec_store_laneseiv2sf = 3480,
  CODE_FOR_vec_store_laneseidi = 3481,
  CODE_FOR_vec_store_lanesciv16qi = 3482,
  CODE_FOR_vec_store_lanesciv8hi = 3483,
  CODE_FOR_vec_store_lanesciv8hf = 3484,
  CODE_FOR_vec_store_lanesciv4si = 3485,
  CODE_FOR_vec_store_lanesciv4sf = 3486,
  CODE_FOR_neon_vst3v16qi = 3487,
  CODE_FOR_neon_vst3v8hi = 3488,
  CODE_FOR_neon_vst3v8hf = 3489,
  CODE_FOR_neon_vst3v4si = 3490,
  CODE_FOR_neon_vst3v4sf = 3491,
  CODE_FOR_vec_load_lanesoiv8qi = 3492,
  CODE_FOR_vec_load_lanesoiv4hi = 3493,
  CODE_FOR_vec_load_lanesoiv4hf = 3494,
  CODE_FOR_vec_load_lanesoiv2si = 3495,
  CODE_FOR_vec_load_lanesoiv2sf = 3496,
  CODE_FOR_vec_load_lanesoidi = 3497,
  CODE_FOR_vec_load_lanesxiv16qi = 3498,
  CODE_FOR_vec_load_lanesxiv8hi = 3499,
  CODE_FOR_vec_load_lanesxiv8hf = 3500,
  CODE_FOR_vec_load_lanesxiv4si = 3501,
  CODE_FOR_vec_load_lanesxiv4sf = 3502,
  CODE_FOR_neon_vld4v16qi = 3503,
  CODE_FOR_neon_vld4v8hi = 3504,
  CODE_FOR_neon_vld4v8hf = 3505,
  CODE_FOR_neon_vld4v4si = 3506,
  CODE_FOR_neon_vld4v4sf = 3507,
  CODE_FOR_vec_store_lanesoiv8qi = 3508,
  CODE_FOR_vec_store_lanesoiv4hi = 3509,
  CODE_FOR_vec_store_lanesoiv4hf = 3510,
  CODE_FOR_vec_store_lanesoiv2si = 3511,
  CODE_FOR_vec_store_lanesoiv2sf = 3512,
  CODE_FOR_vec_store_lanesoidi = 3513,
  CODE_FOR_vec_store_lanesxiv16qi = 3514,
  CODE_FOR_vec_store_lanesxiv8hi = 3515,
  CODE_FOR_vec_store_lanesxiv8hf = 3516,
  CODE_FOR_vec_store_lanesxiv4si = 3517,
  CODE_FOR_vec_store_lanesxiv4sf = 3518,
  CODE_FOR_neon_vst4v16qi = 3519,
  CODE_FOR_neon_vst4v8hi = 3520,
  CODE_FOR_neon_vst4v8hf = 3521,
  CODE_FOR_neon_vst4v4si = 3522,
  CODE_FOR_neon_vst4v4sf = 3523,
  CODE_FOR_vec_unpacks_hi_v16qi = 3524,
  CODE_FOR_vec_unpacku_hi_v16qi = 3525,
  CODE_FOR_vec_unpacks_hi_v8hi = 3526,
  CODE_FOR_vec_unpacku_hi_v8hi = 3527,
  CODE_FOR_vec_unpacks_hi_v4si = 3528,
  CODE_FOR_vec_unpacku_hi_v4si = 3529,
  CODE_FOR_vec_unpacks_lo_v16qi = 3530,
  CODE_FOR_vec_unpacku_lo_v16qi = 3531,
  CODE_FOR_vec_unpacks_lo_v8hi = 3532,
  CODE_FOR_vec_unpacku_lo_v8hi = 3533,
  CODE_FOR_vec_unpacks_lo_v4si = 3534,
  CODE_FOR_vec_unpacku_lo_v4si = 3535,
  CODE_FOR_vec_widen_smult_lo_v16qi = 3536,
  CODE_FOR_vec_widen_umult_lo_v16qi = 3537,
  CODE_FOR_vec_widen_smult_lo_v8hi = 3538,
  CODE_FOR_vec_widen_umult_lo_v8hi = 3539,
  CODE_FOR_vec_widen_smult_lo_v4si = 3540,
  CODE_FOR_vec_widen_umult_lo_v4si = 3541,
  CODE_FOR_vec_widen_smult_hi_v16qi = 3542,
  CODE_FOR_vec_widen_umult_hi_v16qi = 3543,
  CODE_FOR_vec_widen_smult_hi_v8hi = 3544,
  CODE_FOR_vec_widen_umult_hi_v8hi = 3545,
  CODE_FOR_vec_widen_smult_hi_v4si = 3546,
  CODE_FOR_vec_widen_umult_hi_v4si = 3547,
  CODE_FOR_vec_widen_sshiftl_lo_v16qi = 3548,
  CODE_FOR_vec_widen_ushiftl_lo_v16qi = 3549,
  CODE_FOR_vec_widen_sshiftl_lo_v8hi = 3550,
  CODE_FOR_vec_widen_ushiftl_lo_v8hi = 3551,
  CODE_FOR_vec_widen_sshiftl_lo_v4si = 3552,
  CODE_FOR_vec_widen_ushiftl_lo_v4si = 3553,
  CODE_FOR_vec_widen_sshiftl_hi_v16qi = 3554,
  CODE_FOR_vec_widen_ushiftl_hi_v16qi = 3555,
  CODE_FOR_vec_widen_sshiftl_hi_v8hi = 3556,
  CODE_FOR_vec_widen_ushiftl_hi_v8hi = 3557,
  CODE_FOR_vec_widen_sshiftl_hi_v4si = 3558,
  CODE_FOR_vec_widen_ushiftl_hi_v4si = 3559,
  CODE_FOR_vec_unpacks_lo_v8qi = 3560,
  CODE_FOR_vec_unpacku_lo_v8qi = 3561,
  CODE_FOR_vec_unpacks_lo_v4hi = 3562,
  CODE_FOR_vec_unpacku_lo_v4hi = 3563,
  CODE_FOR_vec_unpacks_lo_v2si = 3564,
  CODE_FOR_vec_unpacku_lo_v2si = 3565,
  CODE_FOR_vec_unpacks_hi_v8qi = 3566,
  CODE_FOR_vec_unpacku_hi_v8qi = 3567,
  CODE_FOR_vec_unpacks_hi_v4hi = 3568,
  CODE_FOR_vec_unpacku_hi_v4hi = 3569,
  CODE_FOR_vec_unpacks_hi_v2si = 3570,
  CODE_FOR_vec_unpacku_hi_v2si = 3571,
  CODE_FOR_vec_widen_smult_hi_v8qi = 3572,
  CODE_FOR_vec_widen_umult_hi_v8qi = 3573,
  CODE_FOR_vec_widen_smult_hi_v4hi = 3574,
  CODE_FOR_vec_widen_umult_hi_v4hi = 3575,
  CODE_FOR_vec_widen_smult_hi_v2si = 3576,
  CODE_FOR_vec_widen_umult_hi_v2si = 3577,
  CODE_FOR_vec_widen_smult_lo_v8qi = 3578,
  CODE_FOR_vec_widen_umult_lo_v8qi = 3579,
  CODE_FOR_vec_widen_smult_lo_v4hi = 3580,
  CODE_FOR_vec_widen_umult_lo_v4hi = 3581,
  CODE_FOR_vec_widen_smult_lo_v2si = 3582,
  CODE_FOR_vec_widen_umult_lo_v2si = 3583,
  CODE_FOR_vec_widen_sshiftl_hi_v8qi = 3584,
  CODE_FOR_vec_widen_ushiftl_hi_v8qi = 3585,
  CODE_FOR_vec_widen_sshiftl_hi_v4hi = 3586,
  CODE_FOR_vec_widen_ushiftl_hi_v4hi = 3587,
  CODE_FOR_vec_widen_sshiftl_hi_v2si = 3588,
  CODE_FOR_vec_widen_ushiftl_hi_v2si = 3589,
  CODE_FOR_vec_widen_sshiftl_lo_v8qi = 3590,
  CODE_FOR_vec_widen_ushiftl_lo_v8qi = 3591,
  CODE_FOR_vec_widen_sshiftl_lo_v4hi = 3592,
  CODE_FOR_vec_widen_ushiftl_lo_v4hi = 3593,
  CODE_FOR_vec_widen_sshiftl_lo_v2si = 3594,
  CODE_FOR_vec_widen_ushiftl_lo_v2si = 3595,
  CODE_FOR_vec_pack_trunc_v4hi = 3596,
  CODE_FOR_vec_pack_trunc_v2si = 3597,
  CODE_FOR_vec_pack_trunc_di = 3598,
  CODE_FOR_memory_barrier = 3599,
   CODE_FOR_atomic_loaddi = CODE_FOR_nothing,
  CODE_FOR_atomic_compare_and_swapqi = 3600,
  CODE_FOR_atomic_compare_and_swaphi = 3601,
  CODE_FOR_atomic_compare_and_swapsi = 3602,
   CODE_FOR_atomic_compare_and_swapdi = CODE_FOR_nothing,
  CODE_FOR_mulqq3 = 3603,
  CODE_FOR_mulhq3 = 3604,
  CODE_FOR_mulsq3 = 3605,
  CODE_FOR_mulsa3 = 3606,
  CODE_FOR_mulusa3 = 3607,
  CODE_FOR_mulha3 = 3608,
  CODE_FOR_muluha3 = 3609,
  CODE_FOR_ssmulha3 = 3610,
  CODE_FOR_usmuluha3 = 3611
};

const unsigned int NUM_INSN_CODES = 4210;
#endif /* GCC_INSN_CODES_H */
